%global __spec_install_pre %{___build_pre}

Summary: The Linux Realtime kernel

# mrgN
%global iteration 56

# The preempt RT patch level
%global rttag %{!?rt_patch_version:rt37}

# Do we have a -stable update to apply?
%global stable_update 23

# conditional with/without variables
# Note that the logic here is inverted; a  bcond_without implies
# that the variable is on by default (since you use --without to turn it off)
# Likewise a bcond_with implies the variable is off by default (turned on by --with)
%bcond_without rt
%bcond_without doc
%bcond_without debug
%bcond_with    headers
%bcond_without vanilla
%bcond_without trace
%bcond_with    perf
%bcond_without firmware
%bcond_with    virt
%bcond_without debuginfo
%bcond_without dracut
%bcond_without release

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows it.
# Note that these are regular macros, not the bcond macros defined above,
# so they can be reassigned inside the spec file.

%global buildrt        %{with rt}
%global builddoc       %{with doc}
%global builddebug     %{with debug}
%global buildheaders   %{with headers}
%global buildvanilla   %{with vanilla}
%global buildtrace     %{with trace}
%global buildperf      %{with perf}
%global buildfirmware  %{with firmware}
%global buildvirt      %{with virt}
%global builddebuginfo %{with debuginfo}
%global buildrelease   %{with release}


#
# this is the MRG release number which will go into 
#       /etc/mrg-realtime-release
# The format is <major>.<minor>.<errata>

%if %{buildrelease}
%global mrg_major	2
%global mrg_minor	2
%global mrg_errata	0
%global mrg_release  	%{mrg_major}.%{mrg_minor}.%{mrg_errata}
%endif

# use dracut or mkinitrd?
%global use_dracut    %{with dracut}

# For a stable, released kernel, released_kernel should be 1. For rawhide
# and/or a kernel built from an rc or git snapshot, released_kernel should
# be 0.
%global released_kernel 1

# Versions of various parts

# Polite request for people who spin their own kernel rpms:
# please modify the "buildid" define in a way that identifies
# that the kernel isn't the stock distribution kernel, for example,
# by setting the define to ".local" or ".bz123456"
#
# % define buildid .local

%global rhel 1
%if %{rhel}
%global distro_build  0
### %global signmodules 1
%global signmodules 0
%else
# fedora_build defines which build revision of this kernel version we're
# building. Rather than incrementing forever, as with the prior versioning
# setup, we set fedora_cvs_origin to the current cvs revision s/1.// of the
# kernel spec when the kernel is rebased, so fedora_build automatically
# works out to the offset from the rebase, so it doesn't get too ginormous.
#
# If you're building on a branch, the RCS revision will be something like
# 1.1205.1.1.  In this case we drop the initial 1, subtract fedora_cvs_origin
# from the second number, and then append the rest of the RCS string as is.
# Don't stare at the awk too long, you'll go blind.
%global fedora_cvs_origin   1462
%global fedora_cvs_revision() %2
%global distro_build %(echo %{fedora_cvs_origin}.%{fedora_cvs_revision $Revision: 1.694 $} | awk -F . '{ OFS = "."; ORS = ""; print $3 - $1 ; i = 4 ; OFS = ""; while (i <= NF) { print ".", $i ; i++} }')
%global distro_build %{fedora_build}
%global signmodules 0
%endif

# if patch fuzzy patch applying will be forbidden
%global with_fuzzy_patches 0

# base_sublevel is the kernel version we're starting with and patching
# on top of -- for example, 2.6.22-rc7-git1 starts with a 2.6.21 base,
# which yields a base_sublevel of 21.
%global base_sublevel 2

## If this is a released kernel ##
%if 0%{?released_kernel}

# Fix a misnaming in later RT patches
%global stable_minor_rev 0
%if 0%{?stable_minor_rev}
%global stable_minor .%{stable_minor_rev}
%endif

# Is it a -stable RC?
%global stable_rc 0
# Set rpm version accordingly
%if 0%{?stable_update}
%global stablerev .%{stable_update}
%global stable_base %{stable_update}
%if 0%{?stable_rc}
# stable RCs are incremental patches, so we need the previous stable patch
%global stable_base %(echo $((%{stable_update} - 1)))
%endif
%endif
%global rpmversion 3.%{base_sublevel}%{?stablerev}%{?stable_minor}

## The not-released-kernel case ##
%else
# The next upstream release sublevel (base_sublevel+1)
%global upstream_sublevel %(echo $((%{base_sublevel} + 1)))
# The rc snapshot level
%global rcrev 0
# The git snapshot level
%global gitrev 0
# Set rpm version accordingly
%global rpmversion 3.%{upstream_sublevel}
%endif
# Nb: The above rcrev and gitrev values automagically define Patch00 and Patch01 below.

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows it.
# All should default to 1 (enabled) and be flipped to 0 (disabled)
# by later arch-specific checks.

# The following build options are enabled by default.
# Use either --without <opt> in your rpmbuild command or force values
# to 0 in here to disable them.
#
# perf noarch subpkg
%global with_vdso_install 1

# Build the kernel-doc package, but don't fail the build if it botches.
# Here "true" means "continue" and "false" means "fail the build".
%if 0%{?released_kernel}
%global doc_build_fail false
%else
%global doc_build_fail true
%endif

# Additional options for user-friendly one-off kernel building:
# Only build the base kernel (--with baseonly):
%global with_baseonly  0
# Only build the debug kernel (--with dbgonly):
%global with_dbgonly   0

# should we do C=1 builds with sparse
%global with_sparse	%{?_with_sparse:      1} %{?!_with_sparse:      0}

# pkg_release is what we'll fill in for the rpm Release: field
%if 0%{?released_kernel}

%if 0%{?stable_rc}
%global stable_rctag .rc%{stable_rc}
%endif
### Old naming convention w/o rtX
### %global pkg_release %{distro_build}%{?stable_rctag}%{?dist}%{?buildid}
### %global pkg_release %{rttag}.%{iteration}%{distro_build}%{?stable_rctag}%{?dist}%{?buildid}
%global pkg_release %{rttag}.%{iteration}%{?stable_rctag}.el6rt%{?buildid}

%else

# non-released_kernel
%if 0%{?rcrev}
%global rctag .rc%rcrev
%else
%global rctag .rc0
%endif
%if 0%{?gitrev}
%global gittag .git%gitrev
%else
%global gittag .git0
%endif
### Old naming convention w/o rtX
### %global pkg_release 0.%{distro_build}%{?rctag}%{?gittag}%{?dist}%{?buildid}
### %global pkg_release %{rttag}.%{iteration}.0.%{distro_build}%{?rctag}%{?gittag}%{?dist}%{?buildid}
%global pkg_release %{rttag}.%{iteration}.0.%{?rctag}%{?gittag}.el6rt%{?buildid}
%endif

# The kernel tarball/base version
%global kversion 3.%{base_sublevel}.%{stable_update}

%global make_target bzImage

%global hdrarch %_target_cpu
%global asmarch %_target_cpu

%global using_upstream_branch 0
%if 0%{?upstream_branch:1}
%global stable_update 0
%global using_upstream_branch 1
%global variant -%{upstream_branch}%{?variant_fedora}
### %global pkg_release %{rttag}.%{iteration}.0.%{distro_build}%{upstream_branch_tag}%{?dist}%{?buildid}
%global pkg_release %{rttag}.%{iteration}.0.%{upstream_branch_tag}.el6rt%{?buildid}
%endif

%if %{rhel}
### %global pkg_release %{rttag}.%{iteration}.%{distro_build}%{?dist}%{?buildid}
%global pkg_release %{rttag}.%{iteration}.el6rt%{?buildid}
%endif
%global KVERREL %{rpmversion}-%{pkg_release}.%{_target_cpu}

%if !%{builddebuginfo}
%global _enable_debug_packages 0
%global fancy_debuginfo 0
%else
%global _enable_debug_packages 1
%global fancy_debuginfo 1
%endif
%global debuginfodir /usr/lib/debug

# if requested, only build base kernel
%if %{with_baseonly}
%global builddebug 0
%global buildtrace 0
%global buildvanilla 0
%global buildvirt 0
%global buildperf 0
%global buildheaders 0
%global builddebuginfo 0
%endif

# if requested, only build debug kernel
%if %{with_dbgonly}
%if %{debugbuildsenabled}
%global buildrt 0
%endif
%global buildperf 0
%endif

%global all_x86 i386 i686

%if %{with_vdso_install}
# These arches install vdso/ directories.
%global vdso_arches %{all_x86} x86_64 
%endif


# don't do debug builds on anything but i686 and x86_64
%ifnarch i686 x86_64
%global builddebug 0
%endif

# only package docs if we're noarch
%ifnarch noarch
%global builddoc 0
%global buildfirmware 0
%global buildrelease 0
%endif

# don't build noarch kernels or headers (duh)
%ifarch noarch
%global buildrt 0
%global buildheaders 0
%global buildperf 0
%global buildvirt 0
%global buildtrace 0
%global buildvanilla 0
%global all_arch_configs kernel-rt-%{version}-*.config
%endif

# Per-arch tweaks

%global asmarch x86
%global image_install_path boot
%global kernel_image arch/x86/boot/bzImage

%ifarch %{all_x86}
%global hdrarch i386
### %global all_arch_configs kernel-%{version}-i?86*.config
%global all_arch_configs kernel-rt-%{rpmversion}-i?86-rt*.config
%endif

%ifarch x86_64
### %global all_arch_configs kernel-%{version}-x86_64*.config
%global all_arch_configs kernel-rt-%{rpmversion}-x86_64-rt*.config
%endif

#%global oldconfig_target nonint_oldconfig
%global oldconfig_target oldconfig

# To temporarily exclude an architecture from being built, add it to
# %nobuildarches. Do _NOT_ use the ExclusiveArch: line, because if we
# don't build kernel-headers then the new build system will no longer let
# us use the previous build of that package -- it'll just be completely AWOL.
# Which is a BadThing(tm).

# We don't build a kernel on i386; we only do kernel-headers there,
# and we no longer build for 31bit S390. Same for 32bit sparc and arm.
%global nobuildarches i386 i586 i686 s390 sparc sparc64 ppc ia64 %{arm} noarch

%ifarch %nobuildarches
%global buildrt 0
%global builddebug 0
%global buildvanilla 0
%global buildtrace 0
%global buildvirt 0
%global builddebuginfo 0
%global buildperf 0
%global _enable_debug_packages 0
%endif

#
# Three sets of minimum package version requirements in the form of Conflicts:
# to versions below the minimum
#

#
# First the general kernel 3.0 required versions as per
# Documentation/Changes
#
%global kernel_dot_org_conflicts  ppp < 2.4.3-3, isdn4k-utils < 3.2-32, nfs-utils < 1.0.7-12, e2fsprogs < 1.37-4, util-linux < 2.12, jfsutils < 1.1.7-2, reiserfs-utils < 3.6.19-2, xfsprogs < 2.6.13-4, procps < 3.2.5-6.3, oprofile < 0.9.1-2

#
# Then a series of requirements that are distribution specific, either
# because we add patches for something, or the older versions have
# problems with the newer kernel or lack certain things that make
# integration in the distro harder than needed.
#
%global package_conflicts initscripts < 7.23, udev < 145-11, iptables < 1.3.2-1, ipw2200-firmware < 2.4, iwl4965-firmware < 228.57.2, selinux-policy-targeted < 1.25.3-14, squashfs-tools < 4.0, wireless-tools < 29-3

# We moved the drm include files into kernel-headers, make sure there's
# a recent enough libdrm-devel on the system that doesn't have those.
%global kernel_headers_conflicts libdrm-devel < 2.4.0-0.15

#
# Packages that need to be installed before the kernel is, because the %post
# scripts use them.
#
%global kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, kernel-rt-firmware >= %{rpmversion}-%{pkg_release}, mrg-rt-release >= %{rpmversion}-%{pkg_release}, grubby >= 7.0.4-1, rt-setup, rt-firmware, kernel-firmware

%if %{use_dracut}
%global initrd_prereq  dracut-kernel >= 002-18.git413bcf78
%else
%global initrd_prereq  mkinitrd >= 6.0.61-1
%endif

#
# This macro does requires, provides, conflicts, obsoletes for a kernel package.
#	%%kernel_reqprovconf <subpackage>
# It uses any kernel_<subpackage>_conflicts and kernel_<subpackage>_obsoletes
# macros defined above.
#
%define kernel_reqprovconf \
Provides: kernel = %{rpmversion}-%{pkg_release}\
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{pkg_release}%{?1:.%{1}}\
Provides: kernel-drm = 4.3.0\
Provides: kernel-drm-nouveau = 16\
Provides: kernel-modeset = 1\
Provides: kernel-uname-r = %{KVERREL}%{?1:.%{1}}\
Requires(pre): %{kernel_prereq}\
Requires(pre): %{initrd_prereq}\
Requires(post): /sbin/new-kernel-pkg\
Requires(preun): /sbin/new-kernel-pkg\
Conflicts: %{kernel_dot_org_conflicts}\
Conflicts: %{package_conflicts}\
%{expand:%%{?kernel%{?1:_%{1}}_conflicts:Conflicts: %%{kernel%{?1:_%{1}}_conflicts}}}\
%{expand:%%{?kernel%{?1:_%{1}}_obsoletes:Obsoletes: %%{kernel%{?1:_%{1}}_obsoletes}}}\
%{expand:%%{?kernel%{?1:_%{1}}_provides:Provides: %%{kernel%{?1:_%{1}}_provides}}}\
# We can't let RPM do the dependencies automatic because it'll then pick up\
# a correct but undesirable perl dependency from the module headers which\
# isn't required for the kernel proper to function\
AutoReq: no\
AutoProv: yes\
%{nil}

Name: kernel-rt
Group: System Environment/Kernel
License: GPLv2
URL: http://www.kernel.org/
Version: %{rpmversion}
Release: %{pkg_release}
# DO NOT CHANGE THE 'ExclusiveArch' LINE TO TEMPORARILY EXCLUDE AN ARCHITECTURE BUILD.
# SET %%nobuildarches (ABOVE) INSTEAD
ExclusiveArch: noarch x86_64
ExclusiveOS: Linux
Provides: kernel-rt = %{rpmversion}
Provides: kernel-rt-drm = 4.3.0
Provides: kernel-rt-%{_target_cpu} = %{rpmversion}-%{pkg_release}

%kernel_reqprovconf
%ifarch x86_64
Obsoletes: kernel-smp
%endif

#
# List the packages used during the kernel build
#
BuildRequires: module-init-tools, patch >= 2.5.4, bash >= 2.03, sh-utils, tar
BuildRequires: bzip2, findutils, gzip, m4, perl, make >= 3.78, diffutils, gawk
BuildRequires: gcc >= 3.4.2, binutils >= 2.12, redhat-rpm-config
BuildRequires: net-tools, patchutils, rpm-build >= 4.8.0-7
%if %{builddoc}
BuildRequires: xmlto
BuildRequires: asciidoc
%endif
%if %{with_sparse}
BuildRequires: sparse >= 0.4.1
%endif
%if %{buildrt}
%if %{buildperf}
BuildRequires: elfutils-libelf-devel zlib-devel binutils-devel newt-devel python-devel perl(ExtUtils::Embed) 
BuildRequires: elfutils-devel asciidoc xmlto
%endif
%endif
%if %{signmodules}
BuildRequires: gnupg
%endif
BuildRequires: python

BuildConflicts: rhbuildsys(DiskFree) < 7Gb

%if %{fancy_debuginfo}
# Fancy new debuginfo generation introduced in Fedora 8.
# Note this must be a define since it needs to be overridden in some macro
# expansions
%define debuginfo_args --strict-build-id
%endif

Source0: %{name}-%{rpmversion}-%{pkg_release}.tar.bz2

Source11: genkey
Source12: perf
Source13: perf-archive
Source14: find-provides
Source15: merge.pl
Source17: sanity_check.py
Source19: extrakeys.pub

Source20: %{name}-%{rpmversion}-x86_64-rt.config
Source21: %{name}-%{rpmversion}-x86_64-trace.config
Source22: %{name}-%{rpmversion}-x86_64-debug.config
Source23: %{name}-%{rpmversion}-x86_64-vanilla.config
Source24: %{name}-%{rpmversion}-x86_64-virt.config

#Source20: Makefile.config

### 2.6.33.9-rt31-mrg63.el6rt
### Started using a unified SRPM


# empty final patch file to facilitate testing of kernel patches
#Patch999999: linux-kernel-test.patch

BuildRoot: %{_tmppath}/kernel-%{KVERREL}-root

# Override find_provides to use a script that provides "kernel(symbol) = hash".
# Pass path of the RPM temp dir containing kabideps to find-provides script.
# %global _use_internal_dependency_generator 0
# %global __find_provides %_sourcedir/find-provides %{_tmppath}
# %global __find_requires /usr/lib/rpm/redhat/find-requires kernel

%description
The kernel-rt package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system: memory allocation, process allocation, device
input and output, etc.

This kernel has been compiled withe the RT patch applied and is intended
for use in deterministic response-time situations


%package doc
Summary: Various documentation bits found in the kernel source
Group: Documentation
%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files.

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.


%package headers
Summary: Header files for the Linux kernel for use by glibc
Group: Development/System
Obsoletes: glibc-kernheaders
Provides: glibc-kernheaders = 3.0-46
%description headers
Kernel-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
glibc package.

%package firmware
Summary: Firmware files used by the Linux kernel
Group: Development/System
# This is... complicated.
# Look at the WHENCE file.
License: GPL+ and GPLv2+ and MIT and Redistributable, no modification permitted
Provides: kernel-firmware = %{rpmversion}-%{pkg_release}
Provides: kernel-rt-firmware = %{rpmversion}-%{pkg_release}
%description firmware
Kernel-firmware includes firmware files required for some devices to
operate.

%if %{buildrelease}
%package -n mrg-rt-release
Summary:  MRG Realtime release string
Group:	  Documentation
License:  GPL+
Obsoletes: kernel-rt-release
Provides: mrg-rt-release = %{rpmversion}-%{pkg_release}
Provides: kernel-rt-release = %{rpmversion}-%{pkg_release}
%description -n mrg-rt-release
The MRG release string, which indicates the major, minor and errata release
of the realtime kernel
%endif

%if %{builddebuginfo}
%package debuginfo-common-%{_target_cpu}
Summary: Kernel source files used by %{name}-debuginfo packages
Group: Development/Debug
%description debuginfo-common-%{_target_cpu}
This package is required by %{name}-debuginfo subpackages.
It provides the kernel source files common to all builds.
%endif

%if %{buildrt}
%if %{buildperf}
%package -n perf-rt
Summary: Performance monitoring for the Linux kernel
Group: Development/System
Provides: perl(Perf::Trace::Context), perl(Perf::Trace::Core), perl(Perf::Trace::Util)
License: GPLv2
Obsoletes: perf
%description -n perf-rt
This package provides the supporting documentation for the perf tool
shipped in each kernel image subpackage.
%endif
%endif

#
# This macro creates a kernel-<subpackage>-debuginfo package.
#	%%kernel_debuginfo_package <subpackage>
#
%define kernel_debuginfo_package() \
%package %{?1:%{1}-}debuginfo\
Summary: Debug information for package %{name}%{?1:-%{1}}\
Group: Development/Debug\
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}%{?1:-%{1}}-debuginfo-%{_target_cpu} = %{version}-%{release}\
AutoReqProv: no\
%description -n %{name}%{?1:-%{1}}-debuginfo\
This package provides debug information for package %{name}%{?1:-%{1}}.\
This is required to use SystemTap with %{name}%{?1:%{1}}-%{KVERREL}.\
%{expand:%%global debuginfo_args %{?debuginfo_args} -p '/.*/%%{KVERREL}%{?1:\.%{1}}/.*|/.*%%{KVERREL}%{?1:\.%{1}}(\.debug)?' -o debuginfo%{?1}.list}\
%{nil}

#
# This macro creates a kernel-<subpackage>-devel package.
#	%%kernel_devel_package <subpackage> <pretty-name>
#
%define kernel_devel_package() \
%package %{?1:%{1}-}devel\
Summary: Development package for building kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: kernel-rt%{?1:-%{1}}-devel-%{_target_cpu} = %{version}-%{release}\
Provides: kernel-rt-devel-%{_target_cpu} = %{version}-%{release}%{?1:.%{1}}\
Provides: kernel-rt-devel = %{version}-%{release}%{?1:.%{1}}\
Provides: kernel-rt-devel-uname-r = %{KVERREL}%{?1:.%{1}}\
AutoReqProv: no\
Requires(pre): /usr/bin/find\
%description -n kernel-rt%{?variant}%{?1:-%{1}}-devel\
This package provides kernel headers and makefiles sufficient to build modules\
against the %{?2:%{2} }kernel package.\
%{nil}

#
# This macro creates a kernel-<subpackage> and its -devel and -debuginfo too.
#	%%define variant_summary The Linux kernel compiled for <configuration>
#	%%kernel_variant_package [-n <pretty-name>] <subpackage>
#
%define kernel_variant_package(n:) \
%package %1\
Summary: %{variant_summary}\
Group: System Environment/Kernel\
%kernel_reqprovconf\
%{expand:%%kernel_devel_package %1 %{!?-n:%1}%{?-n:%{-n*}}}\
%{expand:%%kernel_debuginfo_package %1}\
%{nil}


# First the auxiliary packages of the main kernel package.
%kernel_devel_package
%kernel_debuginfo_package

# Now, each variant package.

%if %{with debug}
# kernel-rt-debug
%define variant_summary The Linux kernel compiled with extra debugging enabled
%kernel_variant_package debug
%description debug
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.
%endif

%if %{with trace}
# kernel-rt-trace
%define variant_summary The Linux kernel compiled with extra tracing options enabled
%kernel_variant_package trace
%description trace
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous tracing options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.
%endif

%if %{with vanilla}
# kernel-rt-vanilla
%define variant_summary The Linux kernel compiled without RT capabilities for debugging
%kernel_variant_package vanilla
%description vanilla
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has the realtime capabilities disabled, but
has a configuration close to the one used in the realtime kernel.
It should only be installed when trying to gather additional information
on kernel bugs.
%endif

%if %{with virt}
# kernel-rt-virt
%define variant_summary The Linux kernel compiled with RT and virtualization
%kernel_variant_package virt
%description virt
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has both RT and virtualization options turned on.
It is strictly for internal testing and should never be delivered to a 
customer.
%endif

# macro used to build firmware
%define build_firmware \
   make INSTALL_FW_PATH=$RPM_BUILD_ROOT/lib/firmware/%{rpmversion}-%{pkg_release} firmware_install \
   ln -s /lib/firmware/%{rpmversion}-%{pkg_release} $RPM_BUILD_ROOT/lib/firmware/%{rpmversion}-%{pkg_release}.x86_64 \
   for kvname in debug trace; do \
      ln -s /lib/firmware/%{rpmversion}-%{pkg_release} $RPM_BUILD_ROOT/lib/firmware/%{rpmversion}-%{pkg_release}.x86_64.$kvname \
   done


%prep
if [ ! -d kernel-%{kversion}/vanilla-%{kversion}/ ]; then
	rm -f pax_global_header;
%setup -q -n kernel-%{kversion} -c
	mv %{name}-%{rpmversion}-%{pkg_release} vanilla-%{kversion};
else
	cd kernel-%{kversion}/;
fi

if [ -d linux-%{kversion}.%{_target_cpu} ]; then
  # Just in case we ctrl-c'd a prep already
  rm -rf deleteme.%{_target_cpu}
  # Move away the stale away, and delete in background.
  mv linux-%{kversion}.%{_target_cpu} deleteme.%{_target_cpu}
  rm -rf deleteme.%{_target_cpu} &
fi

cp -rl vanilla-%{kversion} linux-%{kversion}.%{_target_cpu}

cd linux-%{kversion}.%{_target_cpu}

# move off upstream version mechanism
if [ -e localversion-rt ]; then
   mv -f localversion-rt upstream-localversion-rt
fi

# Drop some necessary files from the source dir into the buildroot
#cp $RPM_SOURCE_DIR/config-* .
#cp %{SOURCE15} %{SOURCE17} .

# Dynamically generate kernel .config files from config-* files
#make -f %{SOURCE20} VERSION=%{version} configs

# Any further pre-build tree manipulations happen here.

chmod +x scripts/checkpatch.pl

# only deal with configs if we are going to build for the arch
%ifnarch %nobuildarches

mkdir configs

cp %{SOURCE20} %{SOURCE21} %{SOURCE22} %{SOURCE23} %{SOURCE24} .

# hack to use a new config for the rt-vanilla kernel
#cp %{SOURCE21} kernel-%{version}-x86_64-rtvanilla.config

# Remove configs not for the buildarch
#for cfg in kernel-rt-%{version}-*.config; do
#  if [ `echo %{all_arch_configs} | grep -c $cfg` -eq 0 ]; then
#    rm -f $cfg
#  fi
#done

%if !%{builddebug}
rm -f kernel-rt-%{version}-*debug.config
%endif

# now run oldconfig over all the config files
for i in *.config
do
  echo running oldconfig on $i
  mv $i .config
  Arch=`head -1 .config | cut -b 3-`
  ls -ls .config
  make ARCH=$Arch %{oldconfig_target} >/dev/null
  echo "# $Arch" > configs/$i
  cat .config >> configs/$i
  rm -f include/generated/kernel.arch
  rm -f include/generated/kernel.cross
done
# end of kernel config
%endif

# get rid of unwanted files resulting from patch fuzz
find . \( -name "*.orig" -o -name "*~" \) -exec rm -f {} \; >/dev/null

%if %{signmodules}
cp %{SOURCE19} .
cat <<EOF
###
### Now generating a PGP key pair to be used for signing modules.
###
### If this takes a long time, you might wish to run rngd in the background to
### keep the supply of entropy topped up.  It needs to be run as root, and
### should use a hardware random number generator if one is available, eg:
###
###     rngd -r /dev/hwrandom
###
### If one isn't available, the pseudo-random number generator can be used:
###
###     rngd -r /dev/urandom
###
EOF
gpg --homedir . --batch --gen-key %{SOURCE11}
cat <<EOF
###
### Key pair generated.
###
EOF
# if there're external keys to be included
if [ -s %{SOURCE19} ]; then
	gpg --homedir . --no-default-keyring --keyring kernel.pub --import %{SOURCE19}
fi
gpg --homedir . --export --keyring ./kernel.pub Red > extract.pub
gcc -o scripts/bin2c scripts/bin2c.c
scripts/bin2c ksign_def_public_key __initdata <extract.pub >crypto/signature/key.h
%endif

cd ..

###
### build
###
%build

%if %{with_sparse}
%global sparse_mflags	C=1
%endif

%if %{fancy_debuginfo}
# This override tweaks the kernel makefiles so that we run debugedit on an
# object before embedding it.  When we later run find-debuginfo.sh, it will
# run debugedit again.  The edits it does change the build ID bits embedded
# in the stripped object, but repeating debugedit is a no-op.  We do it
# beforehand to get the proper final build ID bits into the embedded image.
# This affects the vDSO images in vmlinux, and the vmlinux image in bzImage.
export AFTER_LINK=\
'sh -xc "/usr/lib/rpm/debugedit -b $$RPM_BUILD_DIR -d /usr/src/debug -i $@"'
%endif

cp_vmlinux()
{
  eu-strip --remove-comment -o "$2" "$1"
}

BuildKernel() {
    MakeTarget=$1
    KernelImage=$2
    Flavour=$3
    InstallName=${4:-vmlinuz}

    # Pick the right config file for the kernel we're building
    Config=kernel-rt-%{version}-%{_target_cpu}-${Flavour:-rt}.config
    DevelDir=/usr/src/kernels/%{KVERREL}${Flavour:+.${Flavour}}

    # When the bootable image is just the ELF kernel, strip it.
    # We already copy the unstripped file into the debuginfo package.
    if [ "$KernelImage" = vmlinux ]; then
      CopyKernel=cp_vmlinux
    else
      CopyKernel=cp
    fi

    KernelVer=%{version}-%{release}.%{_target_cpu}${Flavour:+.${Flavour}}
    echo BUILDING A KERNEL FOR ${Flavour} %{_target_cpu}...

    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = %{?stable_minor}-%{release}.%{_target_cpu}${Flavour:+.${Flavour}}/" Makefile

    # if pre-rc1 devel kernel, must fix up SUBLEVEL for our versioning scheme
    %if !0%{?rcrev}
    %if 0%{?gitrev}
    perl -p -i -e 's/^SUBLEVEL.*/SUBLEVEL = %{upstream_sublevel}/' Makefile
    %endif
    %endif

    # and now to start the build process

    make -s mrproper
    # HACK ALERT START
    # This is to get around some bnx2x weirdness
    cp ../vanilla-%{version}/firmware/bnx2x/*.fw firmware/bnx2x
    # HACK ALERT END

    cp configs/$Config .config
    echo USING CONFIG configs/$Config

    Arch=`head -1 .config | cut -b 3-`
    echo USING ARCH=$Arch

    make -s ARCH=$Arch %{oldconfig_target} > /dev/null
    make -s ARCH=$Arch V=1 %{?_smp_mflags} $MakeTarget %{?sparse_mflags}
    make -s ARCH=$Arch V=1 %{?_smp_mflags} modules %{?sparse_mflags} || exit 1

%if %{buildrt}
%if %{buildperf}
    if [ -z "$Flavour" ]; then
        pushd tools/perf
        chmod +x util/generate-cmdlist.sh util/PERF-VERSION-GEN
        ### make -s %{?_smp_mflags} V=1 DESTDIR=$RPM_BUILD_ROOT prefix=/usr install
        make -s V=1 %{?_smp_mflags} NO_DEMANGLE=1 perf
        mkdir -p $RPM_BUILD_ROOT/usr/libexec/
        install -m 755 perf $RPM_BUILD_ROOT/usr/libexec/perf.%{KVERREL}%{?Flavour:+.%{Flavour}}
        popd
    fi
%endif
%endif

    # Start installing the results
%if %{builddebuginfo}
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/boot
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/%{image_install_path}
    install -m 644 System.map $RPM_BUILD_ROOT/%{debuginfodir}/boot/System.map-$KernelVer
%endif
    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
%if %{use_dracut}
    # We estimate the size of the initramfs because rpm needs to take this size
    # into consideration when performing disk space calculations. (See bz #530778)
    dd if=/dev/zero of=$RPM_BUILD_ROOT/boot/initramfs-$KernelVer.img bs=1M count=20
%else
    dd if=/dev/zero of=$RPM_BUILD_ROOT/boot/initrd-$KernelVer.img bs=1M count=5
%endif
    if [ -f arch/$Arch/boot/zImage.stub ]; then
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :
    fi
    $CopyKernel $KernelImage \
    		$RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    chmod 755 $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer

    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    # Override $(mod-fw) because we don't want it to install any firmware
    # We'll do that ourselves with 'make firmware_install'
    make -s ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer mod-fw=

      # check if the modules are being signed
%if %{signmodules}
    if [ -z "$(readelf -n $(find fs/ -name \*.ko | head -n 1) | grep module.sig)" ]; then
        echo "ERROR: modules are NOT signed" >&2;
        exit 1;
    fi
%endif

%ifarch %{vdso_arches}
    make -s ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT vdso_install KERNELRELEASE=$KernelVer
    if [ ! -s ldconfig-kernel.conf ]; then
      echo > ldconfig-kernel.conf "\
# Placeholder file, no vDSO hwcap entries used in this kernel."
    fi
    %{__install} -D -m 444 ldconfig-kernel.conf \
        $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernel-rt-$KernelVer.conf
%endif

    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    (cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
    # dirs for additional modules per module-init-tools, kbuild/modules.txt
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/extra
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/updates
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/weak-updates
    # first copy everything
    cp --parents `find  -type f -name "Makefile*" -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -s Module.markers ]; then
      cp Module.markers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    fi

    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Documentation
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -d arch/$Arch/scripts ]; then
      cp -a arch/$Arch/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    fi
    if [ -f arch/$Arch/*lds ]; then
      cp -a arch/$Arch/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    fi
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*.o
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*/*.o

    # hack to remove .build-id conflict with RHEL kernel debuginfo
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/conmakehash
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/pnmtologo

    if [ -d arch/%{asmarch}/include ]; then
      cp -a --parents arch/%{asmarch}/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cd include
    cp -a $(echo * | sed -e 's/^asm$//') $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    #cp -a acpi config crypto keys linux math-emu media mtd net pcmcia rdma rxrpc scsi sound trace video drm asm-generic generated xen $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    if [ -L asm ]; then
      asmdir=$(readlink asm)
      cp -a $asmdir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/
      pushd $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
      ln -s $asmdir asm
      popd
    fi
    # Make sure the Makefile and version.h have a matching timestamp so that
    # external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/version.h
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/autoconf.h
    # Copy .config to include/config/auto.conf so "make prepare" is unnecessary.
    cp $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/config/auto.conf
    cd ..

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
%if %{builddebuginfo}
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
%endif

    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f >modnames

    # mark modules executable so that strip-to-file can strip them
    xargs --no-run-if-empty chmod u+x < modnames

    # Generate a list of modules for block and networking.
    fgrep /drivers/ modnames | xargs --no-run-if-empty nm -upA |
    sed -n 's,^.*/\([^/]*\.ko\):  *U \(.*\)$,\1 \2,p' > drivers.undef

    collect_modules_list()
    {
      sed -r -n -e "s/^([^ ]+) \\.?($2)\$/\\1/p" drivers.undef |
      LC_ALL=C sort -u > $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
    }

    collect_modules_list networking \
    			 'register_netdev|ieee80211_register_hw|usbnet_probe'
    collect_modules_list block \
    			 'ata_scsi_ioctl|scsi_add_host|scsi_add_host_with_dma|blk_init_queue|register_mtd_blktrans|scsi_esp_register|scsi_register_device_handler'
    collect_modules_list drm \
    			 'drm_open|drm_init'
    collect_modules_list modesetting \
    			 'drm_crtc_init'

    # detect missing or incorrect license tags
    rm -f modinfo
    while read i
    do
      echo -n "${i#$RPM_BUILD_ROOT/lib/modules/$KernelVer/} " >> modinfo
      /sbin/modinfo -l $i >> modinfo
    done < modnames

    egrep -v \
    	  'GPL( v2)?$|Dual BSD/GPL$|Dual MPL/GPL$|GPL and additional rights$' \
	  modinfo && exit 1

    rm -f modinfo modnames

    # remove files that will be auto generated by depmod at rpm -i time
    for i in alias alias.bin ccwmap dep dep.bin ieee1394map inputmap isapnpmap ofmap pcimap seriomap symbols symbols.bin usbmap
    do
      rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$i
    done

    # Move the devel headers out of the root file system
    mkdir -p $RPM_BUILD_ROOT/usr/src/kernels
    mv $RPM_BUILD_ROOT/lib/modules/$KernelVer/build $RPM_BUILD_ROOT/$DevelDir
    ln -sf ../../..$DevelDir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    # copy Module.symvers
    cp Module.symvers $RPM_BUILD_ROOT/$DevelDir
}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot

cd linux-%{kversion}.%{_target_cpu}

%if %{builddebug}
BuildKernel %make_target %kernel_image debug
%endif

%if %{buildtrace}
BuildKernel %make_target %kernel_image trace
%endif

%if %{buildvanilla}
BuildKernel %make_target %kernel_image vanilla
%endif

%if %{buildvirt}
BuildKernel %make_target %kernel_image virt
%endif

# maybe %if %{buildrt}
%if %{buildrt}
BuildKernel %make_target %kernel_image
%endif

%if %{builddoc}
# Make the HTML and man pages.
make -j1 htmldocs mandocs || %{doc_build_fail}

# sometimes non-world-readable files sneak into the kernel source tree
chmod -R a=rX Documentation
find Documentation -type d | xargs chmod u+w
%endif

%if %{buildrt}
%if %{buildperf}
pushd tools/perf
make %{?_smp_mflags} man || %{doc_build_fail}
popd
%endif
%endif

###
### Special hacks for debuginfo subpackages.
###

# This macro is used by %%install, so we must redefine it before that.
%global debug_package %{nil}

%if %{fancy_debuginfo}
%define __debug_install_post \
  /usr/lib/rpm/find-debuginfo.sh %{debuginfo_args} %{_builddir}/%{?buildsubdir}\
%{nil}
%endif

%if %{builddebuginfo}
%ifnarch noarch
%global __debug_package 1
%files -f debugfiles.list debuginfo-common-%{_target_cpu}
%defattr(-,root,root)
%endif
%endif

###
### install
###

%install
# for some reason, on RHEL-5 RPM_BUILD_ROOT doesn't get set
if [ -z "$RPM_BUILD_ROOT" ]; then
	export RPM_BUILD_ROOT="%{buildroot}";
fi

cd linux-%{kversion}.%{_target_cpu}

%if %{buildrelease}
if [ ! -d $RPM_BUILD_ROOT/etc ]
then
	mkdir -p $RPM_BUILD_ROOT/etc
fi
echo "Red Hat MRG Realtime release" %{mrg_release} > $RPM_BUILD_ROOT/etc/mrg-realtime-release
%endif

%if %{builddoc}
docdir=$RPM_BUILD_ROOT%{_datadir}/doc/kernel-rt-doc-%{rpmversion}
man9dir=$RPM_BUILD_ROOT%{_datadir}/man/man9rt

# copy the source over
mkdir -p $docdir
tar -f - --exclude=man --exclude='.*' --exclude=*.xml --exclude=*.tmpl -c Documentation | tar xf - -C $docdir

# Install man pages for the kernel API.
mkdir -p $man9dir
find Documentation/DocBook/man -name '*.9.gz' -print0 |
xargs -0 --no-run-if-empty %{__install} -m 444 -t $man9dir $m
ls $man9dir | grep -q '' || > $man9dir/BROKEN
%endif # builddoc

# perf docs
%if %{buildrt}
%if %{buildperf}
mandir=$RPM_BUILD_ROOT%{_datadir}/man
man1dir=$mandir/man1
pushd tools/perf/Documentation
make install-man mandir=$mandir
popd

pushd $man1dir
for d in *.1; do
 gzip $d;
done
popd

# perf shell wrapper
mkdir -p $RPM_BUILD_ROOT/usr/sbin/
cp $RPM_SOURCE_DIR/perf $RPM_BUILD_ROOT/usr/sbin/perf
chmod 0755 $RPM_BUILD_ROOT/usr/sbin/perf
cp $RPM_SOURCE_DIR/perf-archive $RPM_BUILD_ROOT/usr/sbin/perf-archive
chmod 0755 $RPM_BUILD_ROOT/usr/sbin/perf-archive
mkdir -p $RPM_BUILD_ROOT%{_datadir}/doc/perf
%endif # buildperf
%endif

%if %{buildheaders}
# Install kernel headers
make ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_install

# Do headers_check but don't die if it fails.
make ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_check \
     > hdrwarnings.txt || :
if grep -q exist hdrwarnings.txt; then
   sed s:^$RPM_BUILD_ROOT/usr/include/:: hdrwarnings.txt
   # Temporarily cause a build failure if header inconsistencies.
   # exit 1
fi

find $RPM_BUILD_ROOT/usr/include \
     \( -name .install -o -name .check -o \
     	-name ..install.cmd -o -name ..check.cmd \) | xargs rm -f

# glibc provides scsi headers for itself, for now
rm -rf $RPM_BUILD_ROOT/usr/include/scsi
rm -f $RPM_BUILD_ROOT/usr/include/asm*/atomic.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/io.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/irq.h
%endif

%if %{buildfirmware}
%{build_firmware}
mkdir -p $RPM_BUILD_ROOT%{_datadir}/doc/kernel-rt-%{rpmversion}-%{pkg_release}/firmware
cp firmware/WHENCE $RPM_BUILD_ROOT%{_datadir}/doc/kernel-rt-%{rpmversion}-%{pkg_release}/firmware
%endif

###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

#
# This macro defines a %%post script for a kernel*-devel package.
#	%%kernel_devel_post [<subpackage>]
#
%define kernel_devel_post() \
%{expand:%%post %{?1:%{1}-}devel}\
if [ -f /etc/sysconfig/kernel ]\
then\
    . /etc/sysconfig/kernel || exit $?\
fi\
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ]\
then\
    (cd /usr/src/kernels/%{KVERREL}%{?1:.%{1}} &&\
     /usr/bin/find . -type f | while read f; do\
       hardlink -c /usr/src/kernels/*.fc*.*/$f $f\
     done)\
fi\
%{nil}

# This macro defines a %%posttrans script for a kernel package.
#	%%kernel_variant_posttrans [<subpackage>]
# More text can follow to go at the end of this variant's %%post.
#
# grubby might be called during installation when a boot loader configuration
# file is not present, so just drop any error messages. See BZ#610813 for
# more details.
%define kernel_variant_posttrans() \
%{expand:%%posttrans %{?1}}\
%{expand:\
NEWKERNARGS=""\
(/sbin/grubby --info=`/sbin/grubby --default-kernel`) 2>/dev/null | grep -q crashkernel\
if [ $? -ne 0 ]\
then\
	NEWKERNARGS="--kernel-args=\"crashkernel=auto\""\
fi\
NKPARGS="--mkinitrd --depmod --update"\
%if %{use_dracut}\
NKPARGS="$NKPARGS --dracut"\
%endif\
/sbin/new-kernel-pkg --package kernel-rt%{?1:%{1}} $NKPARGS %{KVERREL}%{?1:.%{1}} $NEWKERNARGS || exit $?\
}\
/sbin/new-kernel-pkg --package kernel-rt%{?1:%{1}} --rpmposttrans %{KVERREL}%{?1:.%{1}} || exit $?\
[ -d /lib/firmware/updates ] || mkdir -p /lib/firmware/updates\
ln -sf /lib/firmware/mrg-rt-firmware /lib/firmware/updates/%{KVERREL}%{?1:.%{1}}\
%{nil}

#
# This macro defines a %%post script for a kernel package and its devel package.
#	%%kernel_variant_post [-v <subpackage>] [-r <replace>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_post(v:r:) \
%{expand:%%kernel_devel_post %{?-v*}}\
%{expand:%%kernel_variant_posttrans %{?-v*}}\
%{expand:%%post %{?-v*}}\
%{-r:\
if [ `uname -i` == "x86_64" -o `uname -i` == "i386" ] &&\
   [ -f /etc/sysconfig/kernel ]; then\
  /bin/sed -r -i -e 's/^DEFAULTKERNEL=%{-r*}$/DEFAULTKERNEL=kernel%{?-v:-%{-v*}}/' /etc/sysconfig/kernel || exit $?\
fi}\
%{expand:\
/sbin/new-kernel-pkg --package kernel-rt%{?-v:-%{-v*}} --install %{KVERREL}%{?-v:.%{-v*}} || exit $?\
}\
%{nil}


# This macro defines a %%preun script for a kernel package.
#	%%kernel_variant_preun <subpackage>
#
%define kernel_variant_preun() \
%{expand:%%preun %{?1}}\
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}%{?1:.%{1}} || exit $?\
%{nil}

# kernel-rt %post script
%kernel_variant_preun 
%kernel_variant_post

%if %{with debug}
# kernel-rt-debug %post script
%kernel_variant_preun debug
%kernel_variant_post -v debug
%endif

%if %{with trace}
# kernel-rt-trace %post script
%kernel_variant_preun trace
%kernel_variant_post -v trace
%endif

%if %{with vanilla}
# kernel-rt-vanilla %post script
%kernel_variant_preun vanilla
%kernel_variant_post -v vanilla
%endif

%if %{with virt}
# kernel-rt-virt %post script
%kernel_variant_preun virt
%kernel_variant_post -v virt
%endif

if [ -x /sbin/ldconfig ]
then
    /sbin/ldconfig -X || exit $?
fi

###
### file lists
###

%if %{buildheaders}
%files headers
%defattr(-,root,root)
/usr/include/*
%endif

%if %{buildfirmware}
%files firmware
%defattr(-,root,root)
/lib/firmware/*
%doc %{_datadir}/doc/kernel-rt-%{rpmversion}-%{pkg_release}/firmware/WHENCE
%endif

# only some architecture builds need kernel-doc
%if %{builddoc}
%files doc
%defattr(-,root,root)
%{_datadir}/doc/kernel-rt-doc-%{rpmversion}/Documentation/*
%dir %{_datadir}/doc/kernel-rt-doc-%{rpmversion}/Documentation
%dir %{_datadir}/doc/kernel-rt-doc-%{rpmversion}
%{_datadir}/man/man9rt/*
%endif

%if %{buildrelease}
%files -n mrg-rt-release
%defattr(-,root,root)
/etc/mrg-realtime-release
%endif

%if %{buildrt}
%if %{buildperf}
%files -n perf-rt
%defattr(-,root,root)
/usr/sbin/perf
/usr/sbin/perf-archive
/usr/libexec/*
%{_datadir}/man/man1/*
%{_datadir}/doc/perf
%endif
%endif

# This is %{image_install_path} on an arch where that includes ELF files,
# or empty otherwise.
%global elf_image_install_path %{?kernel_image_elf:%{image_install_path}}

#
# This macro defines the %%files sections for a kernel package
# and its devel and debuginfo packages.
#	%%kernel_variant_files [-k vmlinux] <condition> <subpackage>
#
%define kernel_variant_files(k:) \
%if %{1}\
%{expand:%%files %{?2}}\
%defattr(-,root,root)\
/%{image_install_path}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-%{KVERREL}%{?2:.%{2}}\
/boot/System.map-%{KVERREL}%{?2:.%{2}}\
/boot/config-%{KVERREL}%{?2:.%{2}}\
%dir /lib/modules/%{KVERREL}%{?2:.%{2}}\
/lib/modules/%{KVERREL}%{?2:.%{2}}/kernel\
/lib/modules/%{KVERREL}%{?2:.%{2}}/extra\
/lib/modules/%{KVERREL}%{?2:.%{2}}/build\
/lib/modules/%{KVERREL}%{?2:.%{2}}/source\
/lib/modules/%{KVERREL}%{?2:.%{2}}/updates\
/lib/modules/%{KVERREL}%{?2:.%{2}}/weak-updates\
%ifarch %{vdso_arches}\
/lib/modules/%{KVERREL}%{?2:.%{2}}/vdso\
/etc/ld.so.conf.d/kernel-rt-%{KVERREL}%{?2:.%{2}}.conf\
%endif\
/lib/modules/%{KVERREL}%{?2:.%{2}}/modules.*\
%if %{use_dracut}\
%ghost /boot/initramfs-%{KVERREL}%{?2:.%{2}}.img\
%else\
%ghost /boot/initrd-%{KVERREL}%{?2:.%{2}}.img\
%endif\
%{expand:%%files %{?2:%{2}-}devel}\
%defattr(-,root,root)\
%dir /usr/src/kernels\
/usr/src/kernels/%{KVERREL}%{?2:.%{2}}\
%if %{builddebuginfo}\
%ifnarch noarch\
%if %{builddebuginfo}\
%if %{fancy_debuginfo}\
%{expand:%%files -f debuginfo%{?2}.list %{?2:%{2}-}debuginfo}\
%{debuginfodir}/boot/System.map-%{KVERREL}%{?2:.%{2}}\
%else\
%{expand:%%files %{?2:%{2}-}debuginfo}\
%endif\
%endif\
%defattr(-,root,root)\
%if %{builddebuginfo}\
%if !%{fancy_debuginfo}\
%if "%{elf_image_install_path}" != ""\
%{debuginfodir}/%{elf_image_install_path}/*-%{KVERREL}%{?2:.%{2}}.debug\
%endif\
%endif\
%{debuginfodir}/lib/modules/%{KVERREL}%{?2:.%{2}}\
%{debuginfodir}/usr/src/kernels/%{KVERREL}%{?2:.%{2}}\
%{debuginfodir}/boot/System.map-%{KVERREL}%{?2:.%{2}}\
%endif\
%endif\
%endif\
%endif\
%{nil}

%kernel_variant_files %{buildrt}

%if %{builddebug}
%kernel_variant_files %{builddebug} debug
%endif

%if %{buildtrace}
%kernel_variant_files %{buildtrace} trace
%endif

%if %{buildvanilla}
%kernel_variant_files %{buildvanilla} vanilla
%endif

%if %{with virt}
%kernel_variant_files %{buildvirt} virt
%endif

%changelog
* Wed Aug 22 2012 Clark Williams <williams@redhat.com> - 3.2.23-rt37.56
- [netdev] mlx4: Don't show RoCE interfaces if the hpn channel is not installed

* Mon Aug 20 2012 Clark Williams <williams@redhat.com> - 3.2.23-rt37.55
- [mrg] work-around build-id conflict by removing conmakehash and 
  pnmtologo from scripts directory after build

* Mon Aug  6 2012 Clark Williams <williams@redhat.com> - 3.2.23-rt37.54
- [mrg] fix bogus dates in changelog

* Thu Jul 26 2012 Clark Williams <williams@redhat.com> - 3.2.23-rt37.53
- [mrg] fixed dangling 'fi' left in scriptlet

* Wed Jul 25 2012 Clark Williams <williams@redhat.com> - 3.2.23-rt37.52
- [mrg] fixed doubled arch value in firmware symlink 

* Wed Jul 25 2012 Clark Williams <williams@redhat.com> - 3.2.23-rt37.51
- [mrg] removed invalid require of linux-firmware from specfile and
  added correct kernel-firmware require

* Tue Jul 24 2012 Clark Williams <williams@redhat.com> - 3.2.23-rt37.50
- [mrg] modified symlink generation to use /lib/firmware/updates and to 
  correctly generate variant names [BZ# 842680]

* Mon Jul 23 2012 Clark Williams <williams@redhat.com> - 3.2.23-rt37.49
- [mrg] added rt-firmware package require and symlink creation

* Thu Jul 19 2012 Clark Williams <williams@redhat.com> - 3.2.23-rt37.48
- [kernel] rebased to 3.2.23-rt37 (RT update)

* Tue Jul 17 2012 Clark Williams <williams@redhat.com> - 3.2.23-rt36.47
- [kernel] rebased to 3.2.23-rt36
- [bnx2x] added required firmware files

* Tue Jul 10 2012 Clark Williams <williams@redhat.com> - 3.2.22-rt34.46
- [kernel] rebased to 3.2.22-rt34
- [kernel] Lookaside cache with high volume of objects hangs the kernel
- [CVE] epoll: clear the tfile_check_list on -ELOOP [CVE-2012-3375]
- [mrg] turned off INTEL_IOMMU_DEFAULT_ON (DMAR flood issue) [BZ# 834583]

* Mon Jul  2 2012 Clark Williams <williams@redhat.com> - 3.2.20-rt32.45
- [mrg] renamed kernel-rt-release package to mrg-rt-release

* Thu Jun 14 2012 Clark Williams <williams@redhat.com> - 3.2.20-rt32.44
- [kernel] rebased to 3.2.20-rt32

* Wed Jun 13 2012 Clark Williams <williams@redhat.com> - 3.2.19-rt30.43
- [kernel-docs] fixed exclude to skip xml and tmpl files in kernel doc

* Mon Jun 11 2012 Clark Williams <williams@redhat.com> - 3.2.19-rt30.42
- [mrg] added exclude for Docbook dir when packaging kernel documentation

* Fri Jun  8 2012 Clark Williams <williams@redhat.com> - 3.2.19-rt30.41
- [kernel] rebased to 3.2.19-rt30

* Thu Jun  7 2012 Clark Williams <williams@redhat.com> - 3.2.18-rt29.40
- from Arnaldo Carvalho de Melo <acme@redhat.com>:
  - [drivers/net] add firmware for rtl8169 from linux-firmware.git (815937)

* Tue Jun  5 2012 Clark Williams <williams@redhat.com> - 3.2.18-rt29.39
- [mrg] reworked kernel-rt-release versioning to be like kernel-rt-firmware

* Thu May 31 2012 John Kacur <jkacur@redhat.com> - 3.2.18-rt29.38
- [mm/hugetlb] fix vma_resv_map() NULL pointer (824354) {CVE-2012-2390}
- [mm/hugetlb] fix resv_map leak in error path (824354) {CVE-2012-2390}
- [mm/hugetlb] use long vars instead of int in region_count (824354) {CVE-2012-2390}
- [mrg] added rpmversion provides/requires for kernel-rt-release
- The following fixes were obtained when rebasing (merging) to v3.2.18
- [drm/i915] fix integer overflow in i915_gem_do_execbuffer (824565) {CVE-2012-2384}
- [drm/i915] fix integer overflow in i915_gem_execbuffer2 (824557) {CVE-2012-2383}

* Wed May 30 2012 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 3.2.18-rt29.37
- [net] updated cnic, qlcnic, tg3, atl1c and be2net from RHEL6

* Fri May 25 2012 Clark Williams <williams@redhat.com> - 3.2.18-rt29.36
- [mrg] undo mistake that dropped us back to 3.2.17

* Fri May 25 2012 Clark Williams <williams@redhat.com> - 3.2.18-rt29.35
- [timers] Add tick skew boot option
- [timers] Move skew_tick option into the HIGH_RES_TIMER section
- [kmod] implemented killable request_module patchset (819736)

* Wed May 23 2012 John Kacur <jkacur@redhat.com> - 3.2.18-rt29.34
- [scsi-qla2xxx] Fix BUG: sleeping function called from invalid context (818220)
- The following fixes were obtained when rebasing (merging) to v3.2.14-rt24
- [ring-buffer/rt] Check for irqs disabled before grabbing reader lock (799399)
- [sched/rt] Fix wait_task_interactive() to test rt_spin_lock state (799391)
- [lglock/rt] Use non-rt for_each_cpu() in -rt code (799389)
- [futex/rt] Fix possible lockup when taking pi_lock in proxy handler (799386)
- timer: Fix hotplug for -rt (799385)

* Tue May 22 2012 Clark Williams <williams@redhat.com> - 3.2.18-rt29.33
- [kernel] rebased to v3.2.18-rt29
- [config] turn off CONFIG_COMPAT_VDSO (822298)
- [config] enabled CONFIG_CRYPTO_FIPS (814689)

* Fri May 18 2012 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 3.2.17-rt28.32
- [mrg] re-added kernel-rt-release sub-package

* Thu May 17 2012 Clark Williams <williams@redhat.com> - 3.2.17-rt28.31
- [mrg] removed dummy codename from /etc/mrg-realtime-release file (817154)

* Tue May 15 2012 Clark Williams <williams@redhat.com> - 3.2.17-rt28.30
- [mrg] rebased to 3.2.17-rt28

* Mon May 14 2012 Clark Williams <williams@redhat.com> - 3.2.16-rt27.29
- [mrg] added Requires: kernel-rt-release to specfile
- [mrg] changed format of kernel-rt-release string to match RHEL

* Tue May  8 2012 Clark Williams <williams@redhat.com> - 3.2.16-rt27.28
- [kernel] cherry-picked RHEL6 "crashkernel=auto" logic

* Mon May  7 2012 Clark Williams <williams@redhat.com> - 3.2.16-rt27.27
- [mrg] added kernel-rt-release sub-package

* Fri May  4 2012 Clark Williams <williams@redhat.com> - 3.2.16-rt27.26
- updates from Arnaldo Carvalho de Melo <acme@redhat.com>:
  - [net] updated enic, be2net, bnx2x, and netxen_nic 10gbe drivers

* Mon Apr 30 2012 Clark Williams <williams@redhat.com> - 3.2.16-rt27.25
- [storage] updated mpt2sas, qla2xxx, qla4xxx, isci, and be2iscsi from upstream
   and RHEL6

* Fri Apr 27 2012 Clark Williams <williams@redhat.com> - 3.2.16-rt27.24
- [storage] updated megaraid_sas to RHEL-6.3 version
- updates from Arnaldo Carvalho de Melo <acme@redhat.com>:
  - [net] update 1gbe NICs to RHEL6.3 versions: bnx2, e1000/e1000e, tg3

* Mon Apr 23 2012 Clark Williams <williams@redhat.com> - 3.2.16-rt27.23
- [mrg] rebase to 3.2.16-rt27 (stable update + RT update)

* Wed Apr 11 2012 Clark Williams <williams@redhat.com> - 3.2.14-rt24.22
- [mrg] rebase to 3.2.14-rt24 (RT update)

* Mon Apr  9 2012 Clark Williams <williams@redhat.com> - 3.2.14-rt23.21
- [mrg] rebase to 3.2.13-rt23 (stable update + RT update)

* Thu Mar 15 2012 Clark Williams <williams@redhat.com> - 3.2.11-rt20.20
- [mrg] update configs to more closely mirror RHEL configs

* Wed Mar 14 2012 Clark Williams <williams@redhat.com> - 3.2.11-rt20.19
- [mrg] rebase to 3.2.11-rt20 (stable update + RT update)

* Tue Mar 13 2012 Clark Williams <williams@redhat.com> - 3.2.10-rt18.18
- [mrg] rebased to 3.2.10-rt18

* Mon Mar 12 2012 Clark Williams <williams@redhat.com> - 3.2.9-rt17.17
- [net] merged acme's cherry-picks for net and mlx4

* Fri Mar  9 2012 Clark Williams <williams@redhat.com> - 3.2.9-rt17.16
- [ib] merged acme's port of dledfords changes for ib

* Thu Mar  8 2012 Clark Williams <williams@redhat.com> - 3.2.9-rt17.15
- [mrg]  rebase to 3.2.9-rt17

* Tue Mar  6 2012 Clark Williams <williams@redhat.com> - 3.2.9-rt16.14
- [mrg]  rebase to 3.2.9-rt16

* Thu Mar  1 2012 Clark Williams <williams@redhat.com> - 3.2.8-rt14.12
- [mrg]  rebase to  3.2.9-rt14

* Fri Feb 22 2012 Clark Williams <williams@redhat.com> - 3.2.7-rt13.11
- [mrg]  rebased to 3.2.7 stable

* Wed Feb 22 2012 Clark Williams <williams@redhat.com> - 3.2.6-rt13.10
- applied Paul McKenney's patch to avoid RCU deadlock with hotplug

* Fri Feb 17 2012 Clark Williams <williams@redhat.com> - 3.2.6-rt13.9
- [mrg] updated configs for consistency

* Wed Feb 15 2012 Clark Williams <williams@redhat.com> - 3.2.6-rt13.8
- [mrg] rebased to -rt13

* Tue Feb 14 2012 Clark Williams <williams@redhat.com> - 3.2.6-rt11.7
- [mrg] - rebased to 3.2.6 stable

* Thu Feb  9 2012 Clark Williams <williams@redhat.com> - 3.2.5-rt11.6
- [mrg] - rebased to 3.2.5-rt11

* Tue Feb  7 2012 Clark Williams <williams@redhat.com> - 3.2.4-rt10.5
- [mrg] - rebased to 3.2.4-rt10

* Thu Feb  2 2012 Clark Williams <williams@redhat.com> - 3.2.2-rt10.4
- [kernel] x86: updated rostedt's patches for dealing with GDB issues

* Tue Jan 31 2012 Clark Williams <williams@redhat.com> - 3.2.2-rt10.3
- [mrg] updated configs to turn on RDS/RDMA protocols

* Thu Jan 26 2012 Clark Williams <williams@redhat.com> - 3.2.2-rt10.2
- [kernel] updated to 3.2.2 stable release

* Wed Jan 25 2012 Clark Williams <williams@redhat.com> - 3.2.0-rt10.1
- [kernel] initial build of 3.2 MRG kernel

* Fri Dec 09 2011 John Kacur <jkacur@redhat.com> - 3.0.9-rt26.45
- Added patch that removes FEER_FAT_M3ERR for i5000_edac
- Added two java-rt memory patches
	1. Allocate RTSJ memory for TCK conformance test.
	2. Add /dev/rmem device driver for real-time JVM testing

* Mon Dec 05 2011 Clark Williams <williams@redhat.com> - 3.0.9-rt26.44
- Removed '--host-only' option from new-kernel-pkg invocation for BZ# 755429

* Wed Nov 30 2011 John Kacur <jkacur@redhat.com> - 3.0.9-rt26.43
- Added fbab58b tasklet/rt: Prevent tasklets from going into infinite spin in RT
- c1e17bb Revert "initial fix for HS22 system hang on MRG 2.1 kernel"
	The revert is for a workaround we no longer need thanks to fbab58b 

* Wed Nov 23 2011 John Kacur <jkacur@redhat.com> - 3.0.9-rt26.42
- Rebased to v3.0.9-rt26
- Added rcu: Drive configuration directly from SMP and PREEMPT

* Mon Nov 14 2011 John Kacur <jkacur@redhat.com> - 3.0.9-rt25.41
- Rebased to v3.0.9-rt25
- Added patch from Luis Claudio R. Goncalves
	md-avoid-a-bogus-BUG_ON-on-RT.patch
- Added patches from John Kacur
	Compile error with allmodconfig and CONFIG_PREEMPT_RT_FULL=y
	Fix macro substitution for sync_rcu_bh() on RT
	Reverting old rt code left over in kernel/cpu.c
	Revert "cpufreq: Convert cpufreq_driver_lock to a raw_spinlock_t"
	put back the Avoid using variable-length arrays in kernel/sys.c patch
	Fix typo in use of BUG_ON_NONRT macro for RT
- Added patch from Clark Williams
	ifdef out include of atomic.h
- Added patch from Thomas Gleixner
	Compile errors also for rc1 nonrt

* Thu Nov 10 2011 John Kacur <jkacur@redhat.com> - 3.0.8-rt23.40
- Added patch from Thomas Gleixner
	rt-lock-migrate-unsymetry-fix.patch
- Added patch from Clark Williams
	initial fix for HS22 system hang on MRG 2.1 kernel

* Wed Nov 9 2011 John Kacur <jkacur@redhat.com> - 3.0.8-rt23.39
- merged 3.0.8-rt23

* Thu Oct 27 2011 John Kacur <jkacur@redhat.com> - 3.0.8-rt20.38
- merged stable update 3.0.8
- cherry-picked be27425dcc516fd08245b047ea57f83b8f6f0903
	Add a personality to report 2.6.x version number
- cherry-picked 683c734cecd9d98b3129c695593fa5d5aa3ec53e from rhel6
	[kernel] kcore: restrict access to the whole memory
- changed configs to enable RCU_BOOST, RCU_BOOST_PRIO=1 and RCU_BOOST_DELAY=500
- Applying mlx4 patch series from Arnaldo Carvalho de Melo
	0001-mlx4-use-pci_dev-revision.patch
	0002-mlx4-remove-unnecessary-read-of-PCI_CAP_ID_EXP.patch
	0003-mlx4_core-Extend-capability-flags-to-64-bits.patch
	0004-mlx4_core-Read-extended-capabilities-into-the-flags-.patch
	0005-mlx4_core-Add-network-flow-counters.patch
	0006-mlx4-do-vlan-cleanup.patch
	0007-mlx4_core-Bump-the-driver-version-to-1.0.patch
	0008-mlx4-Fixing-Ethernet-unicast-packet-steering.patch
	0009-mlx4-decreasing-ref-count-when-removing-mac.patch
	0010-mlx4_en-Assigning-TX-irq-per-ring.patch
	0011-mlx4_en-Removing-reserve-vectors.patch
	0012-mlx4_en-Adjusting-moderation-per-each-ring.patch
	0013-mlx4_en-Added-missing-iounmap-upon-releasing-a-devic.patch
	0014-mlx4_en-Fix-QP-number-calculation-according-to-modul.patch
	0015-mlx4_en-Fix-crash-upon-device-initialization-error.patch
	0016-mlx4_en-Adding-40gb-speed-report-for-ethtool.patch
	0017-mlx4-Fix-vlan-table-overflow.patch
	0018-mlx4_en-Controlling-FCS-header-removal.patch
	0019-mlx4_en-Checksum-counters-per-ring.patch
	0020-mlx4_en-Recording-rx-queue-for-gro-packets.patch
	0021-mlx4_en-Adding-rxhash-support.patch
	0022-mlx4_en-Updating-driver-version.patch

* Thu Oct 20 2011 Clark Williams <williams@redhat.com>  - 3.0.7-rt20.37
- added CONFIG_LOCK_DETECTOR to all configs to get nmi_watchdog /proc entry

* Wed Oct 19 2011 Clark Williams <williams@redhat.com>  - 3.0.7-rt20.36
- rebased to stable update 3.0.7
- rebased to -rt patch -rt20

* Thu Oct 13 2011 Clark Williams <williams@redhat.com>  - 3.0.6-rt18.35
- rebased to 3.0.6-rt18

* Wed Oct 12 2011 Clark Williams <williams@redhat.com>  - 3.0.6-rt17.34
- added rostedt's slab patch for BZ# 744100
- cherry-picked commit 43dd61c9: 
      ftrace: Fix regression of :mod:module function enabling
- cherry-picked commit f7bc8b61: 
      ftrace: Fix regression where ftrace breaks when modules are loaded

* Sun Oct 9 2011 John Kacur <jkacur@redhat.com> - 3.0.6-rt17.33
- reverted sched: "remove useles get_cpu() in sched_fork()"

* Sun Oct 9 2011 John Kacur <jkacur@redhat.com> - 3.0.6-rt17.32
- rebased to 3.0.6-rt17

* Thu Oct 6 2011 John Kacur <jkacur@redhat.com> - 3.0.6-rt16.31
- added rostedt's ksoftirqd-should-not-do-a-trylock-loop-with-rt.patch

* Thu Oct 6 2011 John Kacur <jkacur@redhat.com> - 3.0.6-rt16.30
- added paulmck's RCU-bh for RCU-preempt patch

* Tue Oct  4  2011 Clark Williams <williams@redhat.com> - 3.0.6-rt16.29
- rebased to stable kernel 3.0.6
- rebased to -rt patch -rt16
- added back NO_HZ disabled by default

* Mon Oct  3  2011 Clark Williams <williams@redhat.com> - 3.0.4-rt14.28
- cherry-picked commit 1a51410a for CVE-2011-2494 (BZ# 716849)
- cherry-picked commit 9438fabb for CVE-2011-3191 (BZ# 732873)
- cherry-picked commit a8b0ca17 for CVE-2011-2918 (BZ# 730709)
- cherry-picked commit 6b07d30a for CVE-2011-1161 (BZ# 732634)
- cherry-picked commit 3321c07a for CVE-2011-1162 (BZ# 732634)

* Thu Sep 29  2011 Clark Williams <williams@redhat.com> - 3.0.4-rt14.27
- update WARN on migrating bound threads to take into account valid cases
- cherry-pick upstream commit f632ce2 to avoid tracing arch_* functions
- tracing: Fix preemptirqsoff tracer to not stop at preempt off

* Tue Sep 27  2011 Clark Williams <williams@redhat.com> - 3.0.4-rt14.26
- added rostedt's patch to remove bogus binding of workqueue threads
- added rostedt's WARN_ON patch to catch migrating bounded threads

* Tue Sep 27  2011 Clark Williams <williams@redhat.com> - 3.0.4-rt14.25
- replaced previous patch seris from rostedt/peterz with v2
- updated kernel-rt.spec to -rt14.25
- fixed rtmutex.c borkage with CONFIG_SMP_X

* Mon Sep 26  2011 Clark Williams <williams@redhat.com> - 3.0.4-rt14.24
- reverted two rostedt patches for migrate_disable
- added new rostedt patch for migrate_disable
- added peterz patches for affinity and migrate_disable

* Thu Sep 22  2011 Clark Williams <williams@redhat.com> - 3.0.4-rt14.23
- pulled in tglx patch to revert ptrace preemption magic

* Tue Sep 20  2011 Clark Williams <williams@redhat.com> - 3.0.4-rt14.22
- turned off all cgroups except for cpusets

* Thu Sep 15  2011 Clark Williams <williams@redhat.com> - 3.0.4-rt14.21
- add rostedt migrate-delay-disable patch
- add rostedt patch to make push/pull migrate_disable aware
- comment out WARN_ON_ONCE in migrate_disable

* Wed Sep 14  2011 Clark Williams <williams@redhat.com> - 3.0.4-rt14.20
- rebase to 3.0.4-rt14

* Wed Sep 14  2011 Clark Williams <williams@redhat.com> - 3.0.4-rt13.19
- update configs to make sure virt/KVM configs are only on in -virt config
- add tcp_delack_min /proc tunable
- add peterz's sysv semaphore wakeup modifications
- add Shawn Bohrer's patch to sched_rt for migrating rt tasks

* Mon Sep 12  2011 Clark Williams <williams@redhat.com> - 3.0.4-rt13.18
- add tglx patch to cure load balancing madness

* Sun Sep 11  2011 Clark Williams <williams@redhat.com> - 3.0.4-rt13.17
- rebase to 3.0.4-rt13

* Wed Sep  7  2011 Clark Williams <williams@redhat.com> - 3.0.3-rt12.16
- modify doc paths to be kernel-rt specific
- sched: teach migrate_disable about atomic contexts

* Wed Aug 31  2011 Clark Williams <williams@redhat.com> - 3.0.3-rt12.15
- fix kernel boot issue with extraneous version number

* Tue Aug 30  2011 Clark Williams <williams@redhat.com> - 3.0.3-rt12.14
- rebased to 3.0.3 stable release
- rebased to -rt12 realtime release
- specfile fixes (define -> global changes)

* Wed Aug 24  2011 Clark Williams <williams@redhat.com> - 3.0.1-rt11.13
- updated config files to turn of DEBUG_PREEMPT

* Tue Aug 23  2011 Clark Williams <williams@redhat.com> - 3.0.1-rt11.12
- updated BuildRequires for perf

* Thu Aug 18  2011 Clark Williams <williams@redhat.com> - 3.0.1-rt11.11
- turned off CONFIG_DEBUG_PREEMPT in production configuration

* Wed Aug 15 2011 Clark Williams <williams@redhat.com> - 3.0.1-rt11.10
- add --host-only to %post macros for new-kernel-pkgq

* Mon Aug 15 2011 Clark Williams <williams@redhat.com> - 3.0.1-rt11.8
- modify perf subpackage built to be named perf-rt

* Sun Aug 14 2011 Clark Williams <williams@redhat.com> - 3.0.1-rt11.7
- rebase to realtime patch -rt11
- turned on FAIR_GROUP_SCHED and RT_GROUP_SCHED configs

* Thu Aug 11 2011 Clark Williams <williams@redhat.com> - 3.0.1-rt9.7
- rebase to realtime patch -rt9

* Wed Aug 10 2011 Clark Williams <williams@redhat.com> - 3.0.1-rt8.6
- modify specfile to pull in appropriate includes for -devel package
- add Module.symvers to -devel package

* Fri Aug  5 2011 Clark Williams <williams@redhat.com> - 3.0.1-rt8.5
- rebased to v3.0.1 stable kernel series
- rebased to -rt8 patchset

* Thu Aug  4 2011 Clark Williams <williams@redhat.com> - 3.0.0-rt6.4
- updated configs
  - removed virt options from non-virt kernels
  - turned on PPS and PTP timestamping
  - turned on DEBUG_RT_MUTEXES

* Wed Aug  3 2011 Clark Williams <williams@redhat.com> - 3.0.0-rt6.3
- added rostedt's cpupri patch (commit: 84d342f)

* Mon Aug  1 2011 Clark Williams <williams@redhat.com> - 3.0.0-rt6.2
- fixed localversion-rt issue
- updated specfile to use %bcond_{with,without} macro definitions

* Fri Jul 29 2011 Clark Williams <williams@redhat.com> - 3.0.0-rt6.1
- rebased to -rt6 patchset

* Thu Jul 28 2011 Clark Williams <williams@redhat.com> - 3.0.0-rt5.1
- initial build of 3.0 kernel

* Wed Jul 20 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg73
- bnx2: add missing reference to the a new firmware file in the Makefile

* Mon Jul 11 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg72
- Added missing files to kernel-rt-devel package (J.H.M. Dassen) [718940]

* Wed Jun 29 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg71
- tcp: make ato min and delack min tunable [460217] [717261]

* Tue Jun 28 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg70
- bfa: Use the driver in kernel-2.6.32-163.el6 [712422]
- kdump: implement crashkernel=auto [706961]

* Mon Jun 27 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg69
- Disable TRACE_BRANCH_PROFILING on kernel-rt-trace because of its overhead
- Disable deprecated CONFIG_NF_CT_ACCT option [710158]
- ftrace: update the docs in Documentation and debugfs [716559]
- ftrace: do not disable interrupts for modules in mcount update [715418]
- sched: Fix need_resched() when checking peempt [717081]
- clocksource: Make watchdog robust vs. interruption [717083]

* Fri Jun 10 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg68
- Backported the benet (be2net) driver from kernel-2.6.32-154.el6 [707259]
- Updated the following NIC drivers to the version in kernel-2.6.32-154.el6:
- bna, bnx2, bnx2x, chelsio, e100, enic, igb, ixgb, ixgbe, myri10g, netxen, sfc and tg3
- Enabled CHELSIO_T4, QLCNIC and BNA network driver config options

* Mon Jun 06 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg67
- Relax si_code check in rt_sigqueueinfo and rt_tgsigqueueinfo [711205]

* Wed May 25 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg66
- Backported PCI _CRS fixes from linux-tip

* Tue May 17 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg65
- Added bz705582-rhel6-RCUify-posix_timers.patch
- Disabled CONFIG_BOOTPARAM_HUNG_TASK_PANIC in the debug, vanila and trace kernels

* Mon May 09 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg64
- Re-enabled kernel-rt-vanilla build
- Coupled perf package creation with the production kernel build
- Disabled kernel build for 32bits

* Tue May 03 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.9-rt31.mrg63
- Created symlinks to the firmware files on all kernel-rt variants
- Disable CONFIG_CAN*
- Disabled kernel-rt-vanilla package
- Synchronized with kernel-rt-2.6.33.9-rt31.63.el5rt
- Added bz695829-watchdog-iTCO_wdt-Cleanup-warning-messages.patch
- Added bz680964-mlx4-make-size-of-mcg-entry-module-param.patch
- Added bz688026_CVE-2011-1163-Fix-corrupted-OSF-partition-table-parsing.patch
- Added bz689326-CVE-2011-1170-netfilter-arp_tables-fix-infoleak.patch
- Added bz689335-CVE-2011-1171-netfilter-ip_tables-fix-infoleak.patch
- Added bz689343-netfilter-ipt_CLUSTERIP-fix-buffer-overflow.patch
- Added bz689345_CVE-2011-1172-ipv6-netfilter-ip6_tables-fix-infoleak.patch
- Added bz677269_CVE-2011-0711-xfs-prevent-leaking-uninitialized-stack-mem.patch
- Added bz692665-bnx2x-Fix-PHY-locking-problem.patch
- Added bz681309-Bluetooth-sco-fix-info-leak-to-userspace.patch
- Added bz681317-Bluetooth-bnep-fix-buffer-overflow.patch
- Added bz681324-segoon-openwall.com.patch
- Added bz679308-video-sn9c102-world-wirtable-sysfs-files.patch
- Added bz679308-scsi-aic94xx-world-writable-sysfs-update_bios-file.patch
- Added bz673145-0001-Author-Jerome-Marchand-jmarchan-redhat.com.patch
- Added bz673145-0002-block-fix-accounting-bug-on-cross-partition-merges.patch
- Added bz673145-0003-block-add-internal-hd-part-table-references.patch

* Mon Apr 25 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7.2-rt30-mrg56.4.el6rt
- Added missing firmware files required by newer bnx2 and bnx2x drivers

* Thu Apr 14 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7.2-rt30-mrg56.3.el6rt
- Fixed the EXTRAVERSION handling due to the unique kernel name

* Thu Apr 14 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7.2-rt30-mrg56.1.el6rt
- Added 0000-rhel6-infrastructure-for-NIC-backports.patch
- Added 0001-bna-Use-the-driver-in-kernel-2.6.32-130.el6.patch
- Added 0002-bnx2-Use-the-driver-in-kernel-2.6.32-130.el6.patch
- Added 0003-bnx2x-Use-the-driver-in-kernel-2.6.32-130.el6.patch
- Added 0004-chelsio-Use-the-drivers-in-kernel-2.6.32-130.el6.patch
- Added 0005-e100-e1000-e1000e-Use-the-driver-in-kernel-2.6.32-13.patch
- Added 0006-enic-Use-the-driver-in-kernel-2.6.32-130.el6.patch
- Added 0007-igb-Use-the-driver-in-kernel-2.6.32-130.el6.patch
- Added 0008-ixgb-Use-the-driver-in-kernel-2.6.32-130.el6.patch
- Added 0009-ixgbe-Use-the-driver-in-kernel-2.6.32-130.el6.patch
- Added 0010-myri10g-Use-the-driver-in-kernel-2.6.32-130.el6.patch
- Added 0011-netxen-Use-the-driver-in-kernel-2.6.32-130.el6.patch
- Added 0012-sfc-Use-the-driver-in-kernel-2.6.32-130.el6.patch
- Added 0013-tg3-Use-the-driver-in-kernel-2.6.32-130.el6.patch
- Added perf-backport-from-2.6.28.patch

* Thu Apr 14 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7.2-rt30-mrg56.el6rt
- Synchronized the MRG-2.0 kernel with kernel-rt-2.6.33.7.2-rt30-mrg56
- Incorporated patch-2.6.33.7.2-rt30.bz2
- The following SHA1s refer to commits in v2.6.33.7.2-rt30
- Removed bz625713-Fix-an-Oops-in-the-NFSv4-atomic-open-code.patch
- 	88df8860c784d4d4ba054701c565333fb6317e52
- Removed bz625701-can-add-limit-for-nframes-and-clean-up-signed-unsign.patch
- 	300bc74d197bfbfc7e843b2529e31a93043dfe80
- Removed bz621436-drm-stop-information-leak-of-old-kernel-stack.patch
- Removed bz621436-drm-block-userspace-under-allocating-buffer-and-havi.patch
- The above two patches are equivalent to
-	bf18be070d1b8d87f6ba3c01686e1c8fc3ef0aca
- Removed bz627807-KEYS-Fix-RCU-no-lock-warning-in-keyctl_session_to_pa.patch
-	300f0c0dc280e9ee7a259651d4eb6d3e7ba3488f
- Removed bz627807-KEYS-Fix-bug-in-keyctl_session_to_parent-if-parent-h.patch
-	4d4ea8b53f6dae1fb354b8536a0ead210d6ea6d4
- Removed bz632070-niu-Fix-kernel-buffer-overflow-for-ETHTOOL_GRXCLSRLA.patch
-	1389ed5d809bc8369fa9f9c7f930735397901d6b
- Removed bz631624-tracing-Do-not-allow-llseek-to-set_ftrace_filter.patch
-	dc7dde7adbc57b7461b4b1302c94fe31699f60e2
- Removed bz626316-act_nat-use-stack-variable.patch
-	cd92f998fd8a688dce9b9a7930f6bfbc30d2f918
- Removed bz626316-net-sched-fix-some-kernel-memory-leaks.patch
-	49aa1d9ed423c0d901b5e0c072f1b0269a17a572
- Removed bz628436-wireless-extensions-fix-kernel-heap-content-leak.patch
-	5741fe45da56e3a75eac22942d0fae123ae7d9a0
- Removed bz630553-ALSA-seq-oss-Fix-double-free-at-error-path-of-snd_se.patch
-	85b5abf5021d91c11185e25a542ce1f55b1a0f16
- Removed bz634450-x86-64-compat-Test-rax-for-the-syscall-number-not-ea.patch
-	b2104d5552a93f7efa58be388ad7c3d5faf747ca
- Removed bz634450-x86-64-compat-Retruncate-rax-after-ia32-syscall-entr.patch
-	3609ee783b603f811c3c1d9b2bba3a15dc8030cd
- Removed bz634460-compat-Make-compat_alloc_user_space-incorporate-the.patch
-	c2841fe895b29834edd7137478e2ba19a4a21ef1
- Removed bz607854-mm-make-stack-guard-page-logic-use-vm_prev-pointer.patch
-	3cf7bf56bb62dcb9d99b0060bac4648e2bf8cb16
- Removed bz607854-mm-fix-page-table-unmap-for-stack-guard-page-properl.patch
-	a487cf3a8203643d21d9c14823586e2c72eebaba
- Removed bz607854-mm-fix-missing-page-table-unmap-for-stack-guard-page.patch
-	27ed5f7263e8c301282298ef3d6c911455bba26a
- Removed bz607854-mm-keep-a-guard-page-below-a-grow-down-stack-segment.patch
-	ed313b5159c985cddcc9bc5d3468a7f470c41292
- Removed bz607854-mm-fix-up-some-user-visible-effects-of-the-stack-gua.patch
-	e276f93c1c8ba22adf058e219caaf3fd1e6cecf5
- Removed bz607854-mm-make-the-vma-list-be-doubly-linked.patch
-	498f7001734ff4fb0ef5a494241c1048b1264c0a
- Removed bz607854-mm-make-the-mlock-stack-guard-page-checks-stricter.patch
-	901f364298f4e4a1c3334d291fb90967b25e61de

* Tue Apr 05 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7-rt29-mrg55.3.el6rt
- Our firmware file placement is now RHEL6 compatible

* Wed Mar 23 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7-rt29-mrg55.2.el6rt
- Added missing kernet_variant_post* macros

* Tue Mar 22 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7-rt29-mrg55.1.el6rt
- Reverted the change of firmware files placement

* Tue Mar 15 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7-rt29-mrg55.el6rt
- Changed firmware files placement to be compatible with RHEL6 default
- Re-enabled the kernel-rt-vanilla variant for x86_64
- Added ipt_do_tables_lock_hack.patch to fix kernel-rt-vanilla
- Added bz656833_CVE-2010-4250-notify-stop-kernel-mem-leak-on-file-creat.patch
- Added bz636388_CVE-2010-3477-net-sched-fix-kernel-leak-in-act_police.patch
- Added bz652532_CVE-2010-4162-dont-overflow-pg-count-when-mapping-c.patch
- Added bz652960_CVE-2010-4163-CVE-2010-4668-block-chck-length-of-iov-entries-in-blk.patch
- Added bz659574_CVE-2010-4258-do_exit-check-is-run-with-get_fs-USER_DS.patch
- Added bz637043-Avoid-pgoff-overflow-in-remap_file_pages.patch
- Added bz672405_CVE-2011-0521-media-v3-media-av7110-check-for-negative-array-offse.patch
- Added bz672423_CVE-2010-4656-usb-iowarrior-don-t-trust-report_size.patch
- Added bz652509_CVE-2010-4165-tcp-Increase-TCP_MAXSEG-socket-opt-min.patch
- Added bz656763_CVE-2010-4249-lim-total-scm-lower.patch
- Added bz672436_CVE-2010-4655-net-clear-heap-allocations-for-privileged-ethtool.patch
- Added bz668372_CVE-2010-4649-IB-uverbs-Handle-large-num-of-entries-in-poll-CQ.patch
- Added bz667910_CVE-2010-4648-orinoco-fix-TKIP-countermeasure-behaviour.patch
- Added bz662195_CVE-2010-4346-special_mapping-skips-security_file_mmap.patch
- Added bz655661-CVE-2010-4242_bluetooth-Fix-missing-NULL.patch
- Added bz656269-CVE-2010-4248-posix-cpu-timers-workaround.patch
- Added bz663543_CVE-2010-4347-ACPI-debugfs-custom_method-op.patch
- Added bz664559_CVE-2010-4565-CAN-use-inode-instead.patch
- Reenabled bz465837-rtc-compat-rhel5.patch-ported-to-V2.patch

* Wed Feb 02 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7-rt29.49.3.el6rt
- First attempt at making perf package from kernel-rt compatible with RHEL6 perf.

* Tue Feb 01 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7-rt29.49.2.el6rt
- Re-enabled package kernel-rt-firmware build

* Mon Jan 31 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7-rt29.49.1.el6rt
- Fix perf package missing provides

* Thu Jan 26 2011 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7-rt29.49.el6rt
- Testing rhel6 template for the RT kernel
- Based on 2.6.33.7-rt29.49 (aka 2.6.33.7.2-rt30.1 MRG)

* Wed Jan 12 2011 John Kacur <jkacur@redhat.com> - 2.6.33.7-rt29-mrg49
- Added bz669187.patch
  The above patch includes the update for v2.6.33.7.2-rt30
  In addition it has two fixes, asm-generic-percpu-fixup-RT-mismerge.patch
  and x86-tsc-Prevent-delayed-init-if-initial-tsc-calibrat.patch

* Tue Dec 21 2010 John Kacur <jkacur@redhat.com> - 2.6.33.7-rt29-mrg48
- Added bz651893-CVE-2010-4160-net-Truncate-recvfrom-and-sendto-length-to-INT_MAX.patch
- Added bz660306-x86-Improve-TSC-calibration-using-a-delayed-workqueu.patch

* Mon Nov 22 2010 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7-rt29-mrg47
- Added bz648685-CVE-2010-4072-ipc-shm-fix-information-leak-to-userland.patch
- Added bz648691-CVE-2010-4073-ipc-initialize-structure-memory-to-zero-for-compat-functions.patch
- Added bz648696-CVE-2010-4074-USB-serialmos-prevent-reading-uninitialized-stack-memory.patch
- Added bz648699-CVE-2010-4075-tty-Make-tiocgicount-a-handler.patch
- Added bz648704-CVE-2010-4077-tty-icount-changeover-for-other-main-devices.patch
- Added bz648831-CVE-2010-4079-V4LDVB-ivtvfb-prevent-reading-uninitialized-stack-memory.patch
- Added bz648707-CVE-2010-4080-ALSA-soundpcirme9652-prevent-reading-uninitialized-stack-memory.patch
- Added bz648717-CVE-2010-4082-driversvideoviaioctl.c-prevent-reading-uninitialized-stack-memory.patch
- Added bz648720-CVE-2010-4083-sys_semctl-fix-kernel-stack-leakage.patch
- Added bz651172-CVE-2010-4157-SCSI-gdth-integer-overflow-in-ioctl.patch
- Added bz637689-CVE-2010-2962-drmi915-Sanity-check-preadpwrite.patch
- Added bz642469-CVE-2010-2963-v4l1-fix-32-bit-compat-microcode-loading-translation.patch
- Added bz651674-CVE-2010-4169-perf_events-Fix-perf_counter_mmap-hook-in-mprotect.patch
- Added bz637680-CVE-2010-3432-sctp-Do-not-reset-the-packet-during-sctp_packet_config..patch
- Added bz640460-CVE-2010-3705-sctp-Fix-out-of-bounds-reading-in-sctp_asoc_get_hmac.patch
- Added bz645223-CVE-2010-3858-setup_arg_pages-diagnose-excessive-argument-size.patch
- Added bz646726-CVE-2010-3861-net-clear-heap-allocation-for-ETHTOOL_GRXCLSRLALL.patch
- Added bz651845-CVE-2010-3874-can-bcm-fix-minor-heap-overflow.patch
- Added bz649894-CVE-2010-3876-net-packet-fix-information-leak-to-userland.patch
- Added bz651265-CVE-2010-3880-inet_diag-Make-sure-we-actually-run-the-same-bytecode-we-audited..patch
- Added bz651699-CVE-2010-4158-filter-make-sure-filters-dont-read-uninitialized-memory.patch

* Wed Oct 13 2010 John Kacur <jkacur@redhat.com> - 2.6.33.7-rt29-mrg46
- Added bz638480-ALSA-prevent-heap-corruption-in-snd_ctl_new.patch
- Added bz647434-perf-Mark-software-events-as-irqsafe.patch 
- Modified the kernel-rt.spec file for bz608784

* Wed Oct 6 2010 John Kacur <jkacur@redhat.com> - 2.6.33.7-rt29-mrg45
- Added bz607854-mm-keep-a-guard-page-below-a-grow-down-stack-segment.patch
- Added bz607854-mm-fix-missing-page-table-unmap-for-stack-guard-page.patch
- Added bz607854-x86-don-t-send-SIGBUS-for-kernel-page-faults.patch
- Added bz607854-mm-fix-page-table-unmap-for-stack-guard-page-properl.patch
- Added bz607854-mm-fix-up-some-user-visible-effects-of-the-stack-gua.patch
- Added bz607854-mm-make-the-mlock-stack-guard-page-checks-stricter.patch
- Added bz607854-mm-make-stack-guard-page-logic-use-vm_prev-pointer.patch
- Added bz607854-mm-make-the-vma-list-be-doubly-linked.patch

* Mon Oct 4 2010 Clark Williams <williams@redhat.com> - 2.6.33.7-rt29-mrg44
- removed logic for generating kernel-rt-firmware and requirements for
  that package

* Mon Sep 27 2010 Clark Williams <williams@redhat.com> - 2.6.33.7-rt29-mrg43
- Added manual Provides for perf subpackage

* Sun Sep 26 2010 John Kacur <jkacur@redhat.com> - 2.6.33.7-rt29-mrg42
- Changes to perf

* Tue Sep 21 2010 John Kacur <jkacur@redhat.com> - 2.6.33.7-rt29-mrg41
- CONFIG_HIGHMEM4G=y, and CONFIG_HIGHMEM64G is not set

* Mon Sep 20 2010 John Kacur <jkacur@redhat.com> - 2.6.33.7-rt29-mrg40
- Added bz634460-compat-Make-compat_alloc_user_space-incorporate-the.patch

* Mon Sep 13 2010 John Kacur <jkacur@redhat.com> - 2.6.33.7-rt29-mrg39
- Added bz626316-act_nat-use-stack-variable.patch
- Added bz626316-net-sched-fix-some-kernel-memory-leaks.patch
- Added bz628436-wireless-extensions-fix-kernel-heap-content-leak.patch
- Added bz630553-ALSA-seq-oss-Fix-double-free-at-error-path-of-snd_se.patch
- Added bz634450-x86-64-compat-Test-rax-for-the-syscall-number-not-ea.patch
- Added bz634450-x86-64-compat-Retruncate-rax-after-ia32-syscall-entr.patch
- Added bz629445-aio-check-for-multiplication-overflow-in-do_io_submi.patch
- Added bz633142-drivers-net-usb-hso.c-prevent-reading-uninitialized-.patch
- Added bz633147-drivers-net-eql.c-prevent-reading-uninitialized-stac.patch
- Added bz633151-drivers-net-cxgb3-cxgb3_main.c-prevent-reading-unini.patch

* Thu Sep 9 2010 John Kacur <jkacur@redhat.com> - 2.6.33.7-rt29-mrg38
- Added bz632070-niu-Fix-kernel-buffer-overflow-for-ETHTOOL_GRXCLSRLA.patch
- Added bz631624-tracing-Do-not-allow-llseek-to-set_ftrace_filter.patch
- Reenabled forward-port-of-limit-i386-ram-to-16gb.patch
- Updated and reenabled bz523604-remove-pulse-code-from-the-bnx2x-driver.patch

* Thu Aug 26 2010 John Kacur <jkacur@redhat.com> - 2.6.33.7-rt29-mrg37
- Added bz625713-Fix-an-Oops-in-the-NFSv4-atomic-open-code.patch
- Added bz625701-can-add-limit-for-nframes-and-clean-up-signed-unsign.patch
- Added bz621436-drm-stop-information-leak-of-old-kernel-stack.patch
- Added bz621436-drm-block-userspace-under-allocating-buffer-and-havi.patch
- Added bz627807-KEYS-Fix-RCU-no-lock-warning-in-keyctl_session_to_pa.patch
- Added bz627807-KEYS-Fix-bug-in-keyctl_session_to_parent-if-parent-h.patch
- Turned off CONFIG_LLC

* Tue Aug 17 2010 Luis Claudio R. Goncalves <lgoncalv@redhat.com> - 2.6.33.7-rt29-mrg36
- Removed firmware.patch
- Created the (noarch) kernel-rt-firmware package

* Wed Aug 4 2010 John Kacur <jkacur@redhat.com> - 2.6.33.7-rt29-mrg35
- Rebased to v2.6.33.7-rt29

* Mon Aug 2 2010 John Kacur <jkacur@redhat.com> - 2.6.33.6-rt28-mrg34
- Removed dca-core-cleanup.patch (adds an extra variable, rejected by tglx)
- Turned PAE off
- The following patches can all be removed because they are in -rt28
- Removed consoles-not-working-properly.patch - improved version in -rt28
- Removed 0045-sched-set_cpus_allowed_ptr-Don-t-use-rq-migration_th.patch
- Removed 0046-sched-Kill-the-broken-and-deadlockable-cpuset_lock-c.patch
- Removed 0047-sched-move_task_off_dead_cpu-Take-rq-lock-around-sel.patch
- Removed 0048-sched-move_task_off_dead_cpu-Remove-retry-logic.patch
- Removed 0049-sched-sched_exec-Remove-the-select_fallback_rq-logic.patch
- Removed 0050-sched-_cpu_down-Don-t-play-with-current-cpus_allowed.patch
- Removed 0051-sched-Make-select_fallback_rq-cpuset-friendly.patch
- Removed 0052-0017d735092844118bef006696a750a0e4ef6ebd.patch
- Removed 0053-futex-Protect-against-pi_blocked_on-corruption-durin.patch
- Removed 0054-suspend-Prevent-might-sleep-splats.patch
- Removed 0055-net-iptables-Fix-xt_info-locking.patch
- Removed 0056-x86-mce-Convert-cmci_discover_lock-to-raw_spinlock.patch
- Removed 0057-cpu-hotplug-Don-t-wake-up-the-desched-thread-from-id.patch
- Removed 0058-cpu-hotplug-Prevent-softirq-wakeup-on-wrong-CPU.patch
- Removed 0059-drivers-dca-Convert-dca_lock-to-a-raw-spinlock.patch
- Removed 0060-powerpc-cpu-hotplug-Prevent-softirq-wakeup-on-wrong-.patch
- Removed 0061-dca-Fix-fallout-from-raw_spinlock-conversion.patch

* Thu Jul 29 2010 John Kacur <jkacur@redhat.com> - 2.6.33.6-rt26-mrg33
- Removed convert_dca_lock_to_raw_spinlock_V2.patch (to match git)
- Added dca-core-cleanup.patch (to replace above)

* Thu Jul 28 2010 John Kacur <jkacur@redhat.com> - 2.6.33.6-rt26-mrg32 
- Added consoles-not-working-properly.patch

* Wed Jul 28 2010 John Kacur <jkacur@redhat.com> - 2.6.33.6-rt26-mrg31
- Removed InfiniBand-Add-IBoE-support.patch
- Added bz612275-ibm_rtl-check_DMI_information_in_module_probe.patch
- Removed 0059-drivers-dca-Convert-dca_lock-to-a-raw-spinlock.patch
- Removed 0061-dca-Fix-fallout-from-raw_spinlock-conversion.patch
- Added convert_dca_lock_to_raw_spinlock_V2.patch (Replaces above two)

* Tue Jul 20 2010 Clark Williams <williams@redhat.com> - 2.6.33.6-rt26-mrg30
- merged tip/rt/2.6.33 to pickup:
  - dca_lock fix for igb driver
  - hotplug wakeup fixes
  - TASK_WAKING vs. fork() deadlock fix from peterz
  - various scheduler fixes from oleg
  - PI futex fix from dvhart
  - might_sleep workaround during suspend
  - network fix for xt_info locking

* Sat Jul 17 2010 John Kacur <jkacur@redhat.com> - 2.6.33.6-rt26-mrg29
- Added InfiniBand-Add-IBoE-support.patch

* Wed Jul 14 2010 John Kacur <jkacur@redhat.com> - 2.6.33.6-rt26-mrg28
- Rebasing to 2.6.33.6-rt26
- Removed gianfar-Fix-TX-ring-processing-on-SMP-machines.patch 
- Removed Revert_select_parent_locking_fix.patch
- Removed Make_sure_d_kill_sets_d_parent_to_null.patch
- Removed powerpc-Enable-interrupts-in-do_signal.patch
- Removed powerpc-Disable-sparse-irq-for-RT.patch
- Removed lockdep-Reduce-stack_trace-usage.patch
- Removed bz579408-hvc_console-Fix-race-between-hvc_close-and-hvc_remov.patch
- Removed timer_stats-Convert-table_lock-to-raw_spin_lock.patch
- Removed bz568621-hvc_console-Fix-race-between_close_and_remov.patch
- Removed bz585096-KEYS-find_keyring_by_name-can-gain-access-to-a-freed.patch
- Removed perf_events-fix-errors-path-in-perf_output_begin.patch
- Removed trace-Update-the-comm-field-in-the-right-variable-i.patch

* Tue Jul 13 2010 John Kacur <jkacur@redhat.com> - 2.6.33.5-rt23-mrg27
- Added the bnx2-backport.patch
- Added bnx2x-FW-5.2.13.patch

* Mon Jul 12 2010 John Kacur <jkacur@redhat.com> - 2.6.33.5-rt23-mrg26
- Added no-vfs.patch to revert the dcache problems

* Fri Jul 2 2010 John Kacur <jkacur@redhat.com> - 2.6.33.5-rt23-mrg25
- Added gianfar-Fix-TX-ring-processing-on-SMP-machines.patch
- Renabled bz465837-rtc-compat-rhel5.patch-ported-to-V2.patch

* Wed Jun 30 2010 John Kacur <jkacur@redhat.com> - 2.6.33.5-rt23-mrg24
- The following two patches address the dcache problem
- Added Revert_select_parent_locking_fix.patch
- Added Make_sure_d_kill_sets_d_parent_to_null.patch

* Wed Jun 16 2010 John Kacur <jkacur@redhat.com> - 2.6.33.5-rt23-mrg23
- Added powerpc-Enable-interrupts-in-do_signal.patch
- Added powerpc-Disable-sparse-irq-for-RT.patch
- Added lockdep-Reduce-stack_trace-usage.patch
- Disabled lockdep-Make-MAX_STACK_TRACE_ENTRIES-configurable.patch
- commented out CONFIG_MAX_STACK_TRACE_ENTRIES=393216 in config-debug
- Added bz579408-hvc_console-Fix-race-between-hvc_close-and-hvc_remov.patch
- Added timer_stats-Convert-table_lock-to-raw_spin_lock.patch
- CONFIG_SCSI_MPT2SAS=m added to config-generic
- CONFIG_XFS_FS=m added to config-generic
- CONFIG_XFS_POSIX_ACL=y added to config-generic

* Thu Jun 10 2010 John Kacur <jkacur@redhat.com> - 2.6.33.5-rt23-mrg22
- Rebasing to 2.6.33.5-rt23

* Mon Jun 7 2010 John Kacur <jkacur@redhat.com> - 2.6.33.5-rt22-mrg21
- Replaced nfs4-Prevent-deadlock.patch with Avoid_NFS_igrab_deadlock.patch
- Added Fix_d_genocide-from_decrementing_d_count_more_than_once.patch
- Added Fix_select_parent_dentry_traversal_locking.patch

* Tue Jun 1 2010 John Kacur <jkacur@redhat.com> - 2.6.33.5-rt22-mrg20
- Rebasing to 2.6.33.5-rt22
- Removed net-ehea-make-rx-irq-handler-non-threaded-IRQF_NODEL.patch
- Removed fs-namespace-Fix-fuse-mount-fallout.patch

* Wed May 26 2010 John Kacur <jkacur@redhat.com> - 2.6.33.4-rt20-mrg19
- For the following four i7core_edac patches, see bz582574
- Added i7core_edac-Bring-the-i7core_edac-up-to-date-with-li.patch
- Added i7core_edac-Always-call-i7core_-ur-dimm_check_mc_ecc.patch
- Added i7core_edac-i7core_register_mci-should-not-fall-thro.patch
- Added i7core_edac-Add-support-for-Westmere-to-i7core_edac.patch
- Added nfs4-Prevent-deadlock.patch - see bz596111

* Thu May 20 2010 John Kacur <jkacur@redhat.com> - 2.6.33.4-rt20-mrg18
- Added bz585096-KEYS-find_keyring_by_name-can-gain-access-to-a-freed.patch
- Added net-ehea-make-rx-irq-handler-non-threaded-IRQF_NODEL.patch
- Added fs-namespace-Fix-fuse-mount-fallout.patch

* Tue May 18 2010 John Kacur <jkacur@redhat.com> - 2.6.33.4-rt20-mrg17
- Rebasing to 2.6.33.4-rt20
- Removed fs-Add-missing-parantheses.patch
- Removed autofs-deadlock-fixes.patch
- Removed fs-Fix-mnt_count-typo.patch
- Removed fs-Resolve-mntput_no_expire-issues.patch
- Added perf_events-fix-errors-path-in-perf_output_begin.patch

* Fri May 14 2010 John Kacur <jkacur@redhat.com> - 2.6.33.3-rt19-mrg16
- Added fs-Fix-mnt_count-typo.patch
- Added fs-Resolve-mntput_no_expire-issues.patch

* Tue May 11 2010 John Kacur <jkacur@redhat.com> - 2.6.33.3-rt19-mrg15
- Two fixes from John Stultz for autofs deadlocks

* Thu May 6 2010 John Kacur <jkacur@redhat.com> - 2.6.33.3-rt19-mrg14
- Rebased to 2.6.33.3-rt19
- Started clean-up of the spec file

* Fri Apr 16 2010 John Kacur <jkacur@redhat.com> - 2.6.33.2-rt13-mrg13
- Added tracing-x86-Add-check-to-detect-GCC-messing-with-mco.patch
-	Fixes the problem where the function_graph is not available on 32-bit
- Added lockdep-Make-MAX_STACK_TRACE_ENTRIES-configurable.patch
- Made the default MAX_STACK_TRACE_ENTRIES to 393216 for config-debug

* Fri Apr 9 2010 John Kacur <jkacur@redhat.com> - 2.6.33.2-rt13-mrg12
- Added bz568621-hvc_console-Fix-race-between_close_and_remov.patch

* Wed Apr 7 2010 John Kacur <jkacur@redhat.com> - 2.6.33.2-rt13-mrg11
- Rebased to 2.6.33.2-rt13

* Tue Mar 30 2010 John Kacur <jkacur@redhat.com> - 2.6.33.1-rt11-mrg10
- Added Fix-CONFIG_STACK_TRACER-warning.patch 
- Turned CONFIG_STACK_TRACER back on in the production build
- Added x86-32-clean-up-rwsem-inline-asm-statements.patch
- Added x86-clean-up-rwsem-type-system.patch
- Added x86-64-rwsem-64-bit-xadd-rwsem-implementation.patch
- Added x86-Fix-breakage-of-UML-from-the-changes-in-the-rwse.patch
- Added x86-64-support-native-xadd-rwsem-implementation.patch
- Added x86-64-rwsem-Avoid-store-forwarding-hazard-in-__down.patch
- Added sched-sched_getaffinity-Allow-less-than-NR_CPUS-leng.patch

* Mon Mar 22 2010 John Kacur <jkacur@redhat.com> 2.6.33.1-rt11-mrg9
- rebasing to 2.6.33.1-rt11
- Changing the production config to CONFIG_STACK_TRACER is not set

* Thu Mar 18 2010 John Kacur <jkacur@redhat.com> 2.6.33.1-rt10-mrg8
- rebasing to 2.6.33.1-rt10

* Wed Mar 17 2010 John Kacur <jkacur@redhat.com> - 2.6.33.1-rt9-mrg8
- Rebasing to 2.6.33.1-rt9
- disable the lockbreak-in-load-balancer-for-RT.patch as it is already there

* Tue Mar 16 2010 John Kacur <jkacur@redhat.com> - 2.6.33.1-rt7-mrg7
- Reenabling the IBM patches for raw memory eg:
	- Add-dev-rmem-device-driver-for-real-time-JVM-testing.patch
	- ibm-rmem-for-rtsj.patch
- Added stable patch 2.6.33.1
- added CONFIG_FTRACE=y to config-generic

* Tue Mar 16 2010 John Kacur <jkacur@redhat.com> - 2.6.33-rt7-mrg6
- Added the 0001-lockbreak-in-load-balancer-for-RT.patch

* Fri Mar 12 2010 John Kacur <jkacur@redhat.com> - 2.6.33-rt7-mrg5
- rebased to 2.6.33-rt7
- Due to the rebase, we can drop mm-highmem.c-Fix-pkmap_count-undeclared.patch

* Tue Mar 9 2010 John Kacur <jkacur@redhat.com> - 2.6.33-rt4-mrg4
- disabled forward-port-of-limit-i386-ram-to-16gb.patch
-     the only part of the above patch left was rejected as unnecessary on lkml
- Added trace-Update-the-comm-field-in-the-right-variable-i.patch

* Wed Mar 3 2010 John Kacur <jkacur@redhat.com> - 2.6.33-rt4-mrg3
- Rebased to 2.6.33-rt4
- Added mm-highmem.c-Fix-pkmap_count-undeclared.patch

* Thu Feb 25 2010 John Kacur <jkacur@redhat.com> - 2.6.33-rc8-rt2-mrg2
- Rebased to 2.6.33-rc8-rt2
- Fixed config options, where options are no longer available as modules

* Wed Feb 24 2010 John Kacur <jkacur@redhat.com> - 2.6.33-rc8-rt1-mrg1
- Respinning to 2.6.33-rc8-rt1-mrg1
- Removed many patches, most because they are already in 2.6.33-rc8,
	- some because they need review, and may no-longer apply.

